# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_gcmessages_msgid.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_gcmessages_msgid.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x1b\x64ota_gcmessages_msgid.proto*\xd5\xd7\x01\n\nEDOTAGCMsg\x12\x15\n\x10k_EMsgGCDOTABase\x10\xd8\x36\x12\x1c\n\x17k_EMsgGCGeneralResponse\x10\xd9\x36\x12\x1d\n\x18k_EMsgGCGameMatchSignOut\x10\xdc\x36\x12%\n k_EMsgGCGameMatchSignOutResponse\x10\xdd\x36\x12\x1c\n\x17k_EMsgGCJoinChatChannel\x10\xe1\x36\x12$\n\x1fk_EMsgGCJoinChatChannelResponse\x10\xe2\x36\x12\x1f\n\x1ak_EMsgGCOtherJoinedChannel\x10\xe5\x36\x12\x1d\n\x18k_EMsgGCOtherLeftChannel\x10\xe6\x36\x12\x1d\n\x18k_EMsgGCMatchHistoryList\x10\xe9\x36\x12\"\n\x1dk_EMsgServerToGCRequestStatus\x10\xf2\x36\x12\x1d\n\x18k_EMsgGCGetRecentMatches\x10\xf3\x36\x12\"\n\x1dk_EMsgGCRecentMatchesResponse\x10\xf4\x36\x12\x1e\n\x19k_EMsgGCStartFindingMatch\x10\xf9\x36\x12\x1d\n\x18k_EMsgGCConnectedPlayers\x10\xfa\x36\x12\x1f\n\x1ak_EMsgGCAbandonCurrentGame\x10\xfb\x36\x12\x1d\n\x18k_EMsgGCStopFindingMatch\x10\xfc\x36\x12 \n\x1bk_EMsgGCPracticeLobbyCreate\x10\xfe\x36\x12\x1f\n\x1ak_EMsgGCPracticeLobbyLeave\x10\x80\x37\x12 \n\x1bk_EMsgGCPracticeLobbyLaunch\x10\x81\x37\x12\x1e\n\x19k_EMsgGCPracticeLobbyList\x10\x82\x37\x12&\n!k_EMsgGCPracticeLobbyListResponse\x10\x83\x37\x12\x1e\n\x19k_EMsgGCPracticeLobbyJoin\x10\x84\x37\x12$\n\x1fk_EMsgGCPracticeLobbySetDetails\x10\x86\x37\x12%\n k_EMsgGCPracticeLobbySetTeamSlot\x10\x87\x37\x12)\n$k_EMsgGCInitialQuestionnaireResponse\x10\x89\x37\x12\"\n\x1dk_EMsgGCPracticeLobbyResponse\x10\x8f\x37\x12\"\n\x1dk_EMsgGCBroadcastNotification\x10\x90\x37\x12!\n\x1ck_EMsgGCLiveScoreboardUpdate\x10\x91\x37\x12#\n\x1ek_EMsgGCRequestChatChannelList\x10\x94\x37\x12+\n&k_EMsgGCRequestChatChannelListResponse\x10\x95\x37\x12\x1b\n\x16k_EMsgGCRequestMatches\x10\x98\x37\x12#\n\x1ek_EMsgGCRequestMatchesResponse\x10\x99\x37\x12#\n\x1ek_EMsgGCRequestPlayerResources\x10\x9c\x37\x12+\n&k_EMsgGCRequestPlayerResourcesResponse\x10\x9d\x37\x12\x14\n\x0fk_EMsgGCReadyUp\x10\x9e\x37\x12\'\n\"k_EMsgGCKickedFromMatchmakingQueue\x10\x9f\x37\x12\x1b\n\x16k_EMsgGCLeaverDetected\x10\xa0\x37\x12\x1f\n\x1ak_EMsgGCSpectateFriendGame\x10\xa1\x37\x12\'\n\"k_EMsgGCSpectateFriendGameResponse\x10\xa2\x37\x12\x1a\n\x15k_EMsgGCPlayerReports\x10\xa3\x37\x12$\n\x1fk_EMsgGCReportsRemainingRequest\x10\xa4\x37\x12%\n k_EMsgGCReportsRemainingResponse\x10\xa5\x37\x12\x1f\n\x1ak_EMsgGCSubmitPlayerReport\x10\xa6\x37\x12\'\n\"k_EMsgGCSubmitPlayerReportResponse\x10\xa7\x37\x12\x1e\n\x19k_EMsgGCPracticeLobbyKick\x10\xa9\x37\x12 \n\x1bk_EMsgGCReportCountsRequest\x10\xaa\x37\x12!\n\x1ck_EMsgGCReportCountsResponse\x10\xab\x37\x12\x1d\n\x18k_EMsgGCRequestSaveGames\x10\xac\x37\x12#\n\x1ek_EMsgGCRequestSaveGamesServer\x10\xad\x37\x12%\n k_EMsgGCRequestSaveGamesResponse\x10\xae\x37\x12#\n\x1ek_EMsgGCLeaverDetectedResponse\x10\xaf\x37\x12\"\n\x1dk_EMsgGCPlayerFailedToConnect\x10\xb0\x37\x12\x1d\n\x18k_EMsgGCGCToRelayConnect\x10\xb1\x37\x12%\n k_EMsgGCGCToRelayConnectresponse\x10\xb2\x37\x12\x16\n\x11k_EMsgGCWatchGame\x10\xb3\x37\x12\x1e\n\x19k_EMsgGCWatchGameResponse\x10\xb4\x37\x12\x1d\n\x18k_EMsgGCBanStatusRequest\x10\xb5\x37\x12\x1e\n\x19k_EMsgGCBanStatusResponse\x10\xb6\x37\x12 \n\x1bk_EMsgGCMatchDetailsRequest\x10\xb7\x37\x12!\n\x1ck_EMsgGCMatchDetailsResponse\x10\xb8\x37\x12\x1c\n\x17k_EMsgGCCancelWatchGame\x10\xb9\x37\x12\x1b\n\x16k_EMsgGCProfileRequest\x10\xba\x37\x12\x1c\n\x17k_EMsgGCProfileResponse\x10\xbb\x37\x12\x12\n\rk_EMsgGCPopup\x10\xbe\x37\x12,\n\'k_EMsgGCDOTAClearNotifySuccessfulReport\x10\xc0\x37\x12+\n&k_EMsgGCFriendPracticeLobbyListRequest\x10\xc7\x37\x12,\n\'k_EMsgGCFriendPracticeLobbyListResponse\x10\xc8\x37\x12&\n!k_EMsgGCPracticeLobbyJoinResponse\x10\xc9\x37\x12%\n k_EMsgClientEconNotification_Job\x10\xca\x37\x12\x17\n\x12k_EMsgGCCreateTeam\x10\xcb\x37\x12\x1f\n\x1ak_EMsgGCCreateTeamResponse\x10\xcc\x37\x12\x15\n\x10k_EMsgGCTeamData\x10\xd1\x37\x12#\n\x1ek_EMsgGCTeamInvite_InviterToGC\x10\xd2\x37\x12\x34\n/k_EMsgGCTeamInvite_GCImmediateResponseToInviter\x10\xd3\x37\x12*\n%k_EMsgGCTeamInvite_GCRequestToInvitee\x10\xd4\x37\x12+\n&k_EMsgGCTeamInvite_InviteeResponseToGC\x10\xd5\x37\x12+\n&k_EMsgGCTeamInvite_GCResponseToInviter\x10\xd6\x37\x12+\n&k_EMsgGCTeamInvite_GCResponseToInvitee\x10\xd7\x37\x12\x1b\n\x16k_EMsgGCKickTeamMember\x10\xd8\x37\x12#\n\x1ek_EMsgGCKickTeamMemberResponse\x10\xd9\x37\x12\x16\n\x11k_EMsgGCLeaveTeam\x10\xda\x37\x12\x1e\n\x19k_EMsgGCLeaveTeamResponse\x10\xdb\x37\x12#\n\x1ek_EMsgGCSuggestTeamMatchmaking\x10\xdc\x37\x12%\n k_EMsgGCPlayerHeroesFavoritesAdd\x10\xdd\x37\x12(\n#k_EMsgGCPlayerHeroesFavoritesRemove\x10\xde\x37\x12\x1c\n\x17k_EMsgGCSetShowcaseHero\x10\xe5\x37\x12%\n k_EMsgGCApplyTeamToPracticeLobby\x10\xe6\x37\x12+\n&k_EMsgGCRequestInternatinalTicketEmail\x10\xe7\x37\x12\x1e\n\x19k_EMsgGCTransferTeamAdmin\x10\xe8\x37\x12\x1c\n\x17k_EMsgRequestLeagueInfo\x10\xeb\x37\x12\x1d\n\x18k_EMsgResponseLeagueInfo\x10\xec\x37\x12.\n)k_EMsgGCPracticeLobbyJoinBroadcastChannel\x10\xed\x37\x12!\n\x1ck_EMsgGC_TournamentItemEvent\x10\xee\x37\x12)\n$k_EMsgGC_TournamentItemEventResponse\x10\xef\x37\x12\x18\n\x13k_EMsgCastMatchVote\x10\xf0\x37\x12 \n\x1bk_EMsgCastMatchVoteResponse\x10\xf1\x37\x12\x1c\n\x17k_EMsgRetrieveMatchVote\x10\xf2\x37\x12$\n\x1fk_EMsgRetrieveMatchVoteResponse\x10\xf3\x37\x12\x16\n\x11k_EMsgTeamFanfare\x10\xf4\x37\x12\x1e\n\x19k_EMsgResponseTeamFanfare\x10\xf5\x37\x12&\n!k_EMsgGC_GameServerUploadSaveGame\x10\xf6\x37\x12&\n!k_EMsgGC_GameServerSaveGameResult\x10\xf7\x37\x12#\n\x1ek_EMsgGC_GameServerGetLoadGame\x10\xf8\x37\x12)\n$k_EMsgGC_GameServerGetLoadGameResult\x10\xf9\x37\x12\x1c\n\x17k_EMsgGCEditTeamDetails\x10\xfe\x37\x12$\n\x1fk_EMsgGCEditTeamDetailsResponse\x10\xff\x37\x12\x1f\n\x1ak_EMsgGCProTeamListRequest\x10\x80\x38\x12 \n\x1bk_EMsgGCProTeamListResponse\x10\x81\x38\x12\x1a\n\x15k_EMsgGCReadyUpStatus\x10\x82\x38\x12\x17\n\x12k_EMsgGCHallOfFame\x10\x83\x38\x12\x1e\n\x19k_EMsgGCHallOfFameRequest\x10\x84\x38\x12\x1f\n\x1ak_EMsgGCHallOfFameResponse\x10\x85\x38\x12&\n!k_EMsgGCGenerateDiretidePrizeList\x10\x86\x38\x12!\n\x1ck_EMsgGCRewardDiretidePrizes\x10\x88\x38\x12+\n&k_EMsgGCDiretidePrizesRewardedResponse\x10\x89\x38\x12&\n!k_EMsgGCHalloweenHighScoreRequest\x10\x8a\x38\x12\'\n\"k_EMsgGCHalloweenHighScoreResponse\x10\x8b\x38\x12.\n)k_EMsgGCGenerateDiretidePrizeListResponse\x10\x8c\x38\x12#\n\x1ek_EMsgGCStorePromoPagesRequest\x10\x8e\x38\x12$\n\x1fk_EMsgGCStorePromoPagesResponse\x10\x8f\x38\x12\x1f\n\x1ak_EMsgGCToGCMatchCompleted\x10\x92\x38\x12!\n\x1ck_EMsgGCBalancedShuffleLobby\x10\x94\x38\x12&\n!k_EMsgGCToGCCheckLeaguePermission\x10\x95\x38\x12.\n)k_EMsgGCToGCCheckLeaguePermissionResponse\x10\x96\x38\x12\"\n\x1dk_EMsgGCLeagueScheduleRequest\x10\x97\x38\x12#\n\x1ek_EMsgGCLeagueScheduleResponse\x10\x98\x38\x12\x1f\n\x1ak_EMsgGCLeagueScheduleEdit\x10\x99\x38\x12\'\n\"k_EMsgGCLeagueScheduleEditResponse\x10\x9a\x38\x12\"\n\x1dk_EMsgGCLeaguesInMonthRequest\x10\x9b\x38\x12#\n\x1ek_EMsgGCLeaguesInMonthResponse\x10\x9c\x38\x12$\n\x1fk_EMsgGCMatchmakingStatsRequest\x10\x9d\x38\x12%\n k_EMsgGCMatchmakingStatsResponse\x10\x9e\x38\x12\x1a\n\x15k_EMsgGCBotGameCreate\x10\x9f\x38\x12\"\n\x1dk_EMsgGCSetMatchHistoryAccess\x10\xa0\x38\x12*\n%k_EMsgGCSetMatchHistoryAccessResponse\x10\xa1\x38\x12\x1c\n\x17k_EMsgUpgradeLeagueItem\x10\xa3\x38\x12$\n\x1fk_EMsgUpgradeLeagueItemResponse\x10\xa4\x38\x12%\n k_EMsgGCTeamMemberProfileRequest\x10\xa5\x38\x12\"\n\x1dk_EMsgGCWatchDownloadedReplay\x10\xa6\x38\x12 \n\x1bk_EMsgGCSetMapLocationState\x10\xa7\x38\x12(\n#k_EMsgGCSetMapLocationStateResponse\x10\xa8\x38\x12\x1e\n\x19k_EMsgGCResetMapLocations\x10\xa9\x38\x12&\n!k_EMsgGCResetMapLocationsResponse\x10\xaa\x38\x12\x1d\n\x18k_EMsgGCSetFeaturedItems\x10\xac\x38\x12\x1a\n\x15k_EMsgGCFeaturedItems\x10\xaf\x38\x12$\n\x1fk_EMsgRefreshPartnerAccountLink\x10\xb0\x38\x12$\n\x1fk_EMsgClientsRejoinChatChannels\x10\xb1\x38\x12 \n\x1bk_EMsgGCToGCGetUserChatInfo\x10\xb2\x38\x12(\n#k_EMsgGCToGCGetUserChatInfoResponse\x10\xb3\x38\x12%\n k_EMsgGCToGCLeaveAllChatChannels\x10\xb4\x38\x12%\n k_EMsgGCToGCUpdateAccountChatBan\x10\xb5\x38\x12\x1f\n\x1ak_EMsgGCGuildCreateRequest\x10\xb6\x38\x12 \n\x1bk_EMsgGCGuildCreateResponse\x10\xb7\x38\x12\'\n\"k_EMsgGCGuildSetAccountRoleRequest\x10\xb8\x38\x12(\n#k_EMsgGCGuildSetAccountRoleResponse\x10\xb9\x38\x12\x1d\n\x18k_EMsgGCRequestGuildData\x10\xba\x38\x12\x16\n\x11k_EMsgGCGuildData\x10\xbb\x38\x12&\n!k_EMsgGCGuildInviteAccountRequest\x10\xbc\x38\x12\'\n\"k_EMsgGCGuildInviteAccountResponse\x10\xbd\x38\x12%\n k_EMsgGCGuildCancelInviteRequest\x10\xbe\x38\x12&\n!k_EMsgGCGuildCancelInviteResponse\x10\xbf\x38\x12&\n!k_EMsgGCGuildUpdateDetailsRequest\x10\xc0\x38\x12\'\n\"k_EMsgGCGuildUpdateDetailsResponse\x10\xc1\x38\x12$\n\x1fk_EMsgGCToGCCanInviteUserToTeam\x10\xc2\x38\x12,\n\'k_EMsgGCToGCCanInviteUserToTeamResponse\x10\xc3\x38\x12\x1c\n\x17k_EMsgGCToGCGetUserRank\x10\xc4\x38\x12$\n\x1fk_EMsgGCToGCGetUserRankResponse\x10\xc5\x38\x12 \n\x1bk_EMsgGCToGCUpdateTeamStats\x10\xc8\x38\x12\x1c\n\x17k_EMsgGCToGCGetTeamRank\x10\xc9\x38\x12$\n\x1fk_EMsgGCToGCGetTeamRankResponse\x10\xca\x38\x12 \n\x1bk_EMsgGCPassportDataRequest\x10\xd0\x38\x12!\n\x1ck_EMsgGCPassportDataResponse\x10\xd1\x38\x12\x1b\n\x16k_EMsgGCNotInGuildData\x10\xd3\x38\x12\x1c\n\x17k_EMsgGCGuildInviteData\x10\xd6\x38\x12\x1f\n\x1ak_EMsgGCToGCGetLeagueAdmin\x10\xd7\x38\x12\'\n\"k_EMsgGCToGCGetLeagueAdminResponse\x10\xd8\x38\x12#\n\x1ek_EMsgGCRequestLeaguePrizePool\x10\xda\x38\x12+\n&k_EMsgGCRequestLeaguePrizePoolResponse\x10\xdb\x38\x12,\n\'k_EMsgGCToGCUpdateOpenGuildPartyRequest\x10\xdd\x38\x12-\n(k_EMsgGCToGCUpdateOpenGuildPartyResponse\x10\xde\x38\x12-\n(k_EMsgGCToGCDestroyOpenGuildPartyRequest\x10\xdf\x38\x12.\n)k_EMsgGCToGCDestroyOpenGuildPartyResponse\x10\xe0\x38\x12\x1f\n\x1ak_EMsgGCGuildUpdateMessage\x10\xe1\x38\x12%\n k_EMsgGCPartySetOpenGuildRequest\x10\xe2\x38\x12&\n!k_EMsgGCPartySetOpenGuildResponse\x10\xe3\x38\x12\"\n\x1dk_EMsgGCGuildOpenPartyRefresh\x10\xe4\x38\x12&\n!k_EMsgGCJoinOpenGuildPartyRequest\x10\xe5\x38\x12\'\n\"k_EMsgGCJoinOpenGuildPartyResponse\x10\xe6\x38\x12\x1d\n\x18k_EMsgGCLeaveChatChannel\x10\xe8\x38\x12\x18\n\x13k_EMsgGCChatMessage\x10\xe9\x38\x12\x1d\n\x18k_EMsgGCGetHeroStandings\x10\xea\x38\x12%\n k_EMsgGCGetHeroStandingsResponse\x10\xeb\x38\x12!\n\x1ck_EMsgGCGuildEditLogoRequest\x10\xef\x38\x12\"\n\x1dk_EMsgGCGuildEditLogoResponse\x10\xf0\x38\x12.\n)k_EMsgGCGuildmatePracticeLobbyListRequest\x10\xf1\x38\x12/\n*k_EMsgGCGuildmatePracticeLobbyListResponse\x10\xf2\x38\x12*\n%k_EMsgGCItemEditorReservationsRequest\x10\xf3\x38\x12+\n&k_EMsgGCItemEditorReservationsResponse\x10\xf4\x38\x12%\n k_EMsgGCItemEditorReserveItemDef\x10\xf5\x38\x12-\n(k_EMsgGCItemEditorReserveItemDefResponse\x10\xf6\x38\x12)\n$k_EMsgGCItemEditorReleaseReservation\x10\xf7\x38\x12\x31\n,k_EMsgGCItemEditorReleaseReservationResponse\x10\xf8\x38\x12!\n\x1ck_EMsgGCRewardTutorialPrizes\x10\xf9\x38\x12*\n%k_EMsgGCLastHitChallengeHighScorePost\x10\xfa\x38\x12-\n(k_EMsgGCLastHitChallengeHighScoreRequest\x10\xfb\x38\x12.\n)k_EMsgGCLastHitChallengeHighScoreResponse\x10\xfc\x38\x12\'\n\"k_EMsgGCCreateFantasyLeagueRequest\x10\xfd\x38\x12(\n#k_EMsgGCCreateFantasyLeagueResponse\x10\xfe\x38\x12%\n k_EMsgGCFantasyLeagueInfoRequest\x10\x81\x39\x12&\n!k_EMsgGCFantasyLeagueInfoResponse\x10\x82\x39\x12\x1e\n\x19k_EMsgGCFantasyLeagueInfo\x10\x83\x39\x12%\n k_EMsgGCCreateFantasyTeamRequest\x10\x84\x39\x12&\n!k_EMsgGCCreateFantasyTeamResponse\x10\x85\x39\x12#\n\x1ek_EMsgGCEditFantasyTeamRequest\x10\x86\x39\x12$\n\x1fk_EMsgGCEditFantasyTeamResponse\x10\x87\x39\x12\x34\n/k_EMsgGCFantasyTeamInfoRequestByFantasyLeagueID\x10\x88\x39\x12\x33\n.k_EMsgGCFantasyTeamInfoRequestByOwnerAccountID\x10\x89\x39\x12$\n\x1fk_EMsgGCFantasyTeamInfoResponse\x10\x8a\x39\x12\x1c\n\x17k_EMsgGCFantasyTeamInfo\x10\x8b\x39\x12#\n\x1ek_EMsgGCFantasyLivePlayerStats\x10\x8c\x39\x12$\n\x1fk_EMsgGCFantasyFinalPlayerStats\x10\x8d\x39\x12\x19\n\x14k_EMsgGCFantasyMatch\x10\x8e\x39\x12$\n\x1fk_EMsgGCFantasyTeamScoreRequest\x10\x90\x39\x12%\n k_EMsgGCFantasyTeamScoreResponse\x10\x91\x39\x12(\n#k_EMsgGCFantasyTeamStandingsRequest\x10\x92\x39\x12)\n$k_EMsgGCFantasyTeamStandingsResponse\x10\x93\x39\x12&\n!k_EMsgGCFantasyPlayerScoreRequest\x10\x94\x39\x12\'\n\"k_EMsgGCFantasyPlayerScoreResponse\x10\x95\x39\x12*\n%k_EMsgGCFantasyPlayerStandingsRequest\x10\x96\x39\x12+\n&k_EMsgGCFantasyPlayerStandingsResponse\x10\x97\x39\x12\x1b\n\x16k_EMsgGCFlipLobbyTeams\x10\x98\x39\x12\x1d\n\x18k_EMsgGCCustomGameCreate\x10\x99\x39\x12%\n k_EMsgGCFantasyPlayerInfoRequest\x10\x9a\x39\x12&\n!k_EMsgGCFantasyPlayerInfoResponse\x10\x9b\x39\x12-\n(k_EMsgGCToGCProcessPlayerReportForTarget\x10\x9c\x39\x12%\n k_EMsgGCToGCProcessReportSuccess\x10\x9d\x39\x12%\n k_EMsgGCNotifyAccountFlagsChange\x10\x9e\x39\x12\x1e\n\x19k_EMsgGCSetProfilePrivacy\x10\x9f\x39\x12&\n!k_EMsgGCSetProfilePrivacyResponse\x10\xa0\x39\x12 \n\x1bk_EMsgGCSteamProfileRequest\x10\xa1\x39\x12(\n#k_EMsgGCSteamProfileRequestResponse\x10\xa2\x39\x12+\n&k_EMsgGCFantasyLeagueCreateInfoRequest\x10\xa3\x39\x12,\n\'k_EMsgGCFantasyLeagueCreateInfoResponse\x10\xa4\x39\x12+\n&k_EMsgGCFantasyLeagueInviteInfoRequest\x10\xa5\x39\x12,\n\'k_EMsgGCFantasyLeagueInviteInfoResponse\x10\xa6\x39\x12\x1e\n\x19k_EMsgGCClientIgnoredUser\x10\xa7\x39\x12\'\n\"k_EMsgGCFantasyLeagueCreateRequest\x10\xa8\x39\x12(\n#k_EMsgGCFantasyLeagueCreateResponse\x10\xa9\x39\x12%\n k_EMsgGCFantasyTeamCreateRequest\x10\xaa\x39\x12&\n!k_EMsgGCFantasyTeamCreateResponse\x10\xab\x39\x12/\n*k_EMsgGCFantasyLeagueFriendJoinListRequest\x10\xac\x39\x12\x30\n+k_EMsgGCFantasyLeagueFriendJoinListResponse\x10\xad\x39\x12\x1c\n\x17k_EMsgGCClientSuspended\x10\xae\x39\x12 \n\x1bk_EMsgGCPartyMemberSetCoach\x10\xaf\x39\x12,\n\'k_EMsgGCFantasyLeagueEditInvitesRequest\x10\xb0\x39\x12-\n(k_EMsgGCFantasyLeagueEditInvitesResponse\x10\xb1\x39\x12\"\n\x1dk_EMsgGCPracticeLobbySetCoach\x10\xb2\x39\x12)\n$k_EMsgGCFantasyLeagueEditInfoRequest\x10\xb3\x39\x12*\n%k_EMsgGCFantasyLeagueEditInfoResponse\x10\xb4\x39\x12,\n\'k_EMsgGCFantasyLeagueDraftStatusRequest\x10\xb5\x39\x12%\n k_EMsgGCFantasyLeagueDraftStatus\x10\xb6\x39\x12,\n\'k_EMsgGCFantasyLeagueDraftPlayerRequest\x10\xb7\x39\x12-\n(k_EMsgGCFantasyLeagueDraftPlayerResponse\x10\xb8\x39\x12)\n$k_EMsgGCFantasyLeagueMatchupsRequest\x10\xb9\x39\x12*\n%k_EMsgGCFantasyLeagueMatchupsResponse\x10\xba\x39\x12)\n$k_EMsgGCFantasyTeamRosterSwapRequest\x10\xbb\x39\x12*\n%k_EMsgGCFantasyTeamRosterSwapResponse\x10\xbc\x39\x12%\n k_EMsgGCFantasyTeamRosterRequest\x10\xbd\x39\x12&\n!k_EMsgGCFantasyTeamRosterResponse\x10\xbe\x39\x12\x1f\n\x1ak_EMsgGCNexonPartnerUpdate\x10\xbf\x39\x12*\n%k_EMsgGCToGCProcessPCBangRewardPoints\x10\xc0\x39\x12,\n\'k_EMsgGCFantasyTeamRosterAddDropRequest\x10\xc1\x39\x12-\n(k_EMsgGCFantasyTeamRosterAddDropResponse\x10\xc2\x39\x12&\n!k_EMsgPresentedClientTerminateDlg\x10\xc3\x39\x12/\n*k_EMsgGCFantasyPlayerHisoricalStatsRequest\x10\xc4\x39\x12\x30\n+k_EMsgGCFantasyPlayerHisoricalStatsResponse\x10\xc5\x39\x12%\n k_EMsgGCPCBangTimedRewardMessage\x10\xc6\x39\x12,\n\'k_EMsgGCLobbyUpdateBroadcastChannelInfo\x10\xc7\x39\x12%\n k_EMsgGCFantasyTeamTradesRequest\x10\xc8\x39\x12&\n!k_EMsgGCFantasyTeamTradesResponse\x10\xc9\x39\x12*\n%k_EMsgGCFantasyTeamTradeCancelRequest\x10\xca\x39\x12+\n&k_EMsgGCFantasyTeamTradeCancelResponse\x10\xcb\x39\x12$\n\x1fk_EMsgGCToGCGrantTournamentItem\x10\xcc\x39\x12)\n$k_EMsgGCProcessFantasyScheduledEvent\x10\xcd\x39\x12&\n!k_EMsgGCToGCGrantPCBangRewardItem\x10\xce\x39\x12)\n$k_EMsgGCToGCUpgradeTwitchViewerItems\x10\xcf\x39\x12\'\n\"k_EMsgGCToGCGetLiveMatchAffiliates\x10\xd0\x39\x12/\n*k_EMsgGCToGCGetLiveMatchAffiliatesResponse\x10\xd1\x39\x12*\n%k_EMsgGCToGCUpdatePlayerPennantCounts\x10\xd2\x39\x12\'\n\"k_EMsgGCToGCGetPlayerPennantCounts\x10\xd3\x39\x12/\n*k_EMsgGCToGCGetPlayerPennantCountsResponse\x10\xd4\x39\x12.\n)k_EMsgGCGameMatchSignOutPermissionRequest\x10\xd5\x39\x12/\n*k_EMsgGCGameMatchSignOutPermissionResponse\x10\xd6\x39\x12&\n!k_EMsgDOTAChatChannelMemberUpdate\x10\xd7\x39\x12\x1f\n\x1ak_EMsgDOTAAwardEventPoints\x10\xd8\x39\x12\x1f\n\x1ak_EMsgDOTARedeemEventPrize\x10\xd9\x39\x12\'\n\"k_EMsgDOTARedeemEventPrizeResponse\x10\xda\x39\x12\x1d\n\x18k_EMsgDOTAGetEventPoints\x10\xdb\x39\x12%\n k_EMsgDOTAGetEventPointsResponse\x10\xdc\x39\x12(\n#k_EMsgGCToGCSignoutAwardEventPoints\x10\xde\x39\x12!\n\x1ck_EMsgDOTASendFriendRecruits\x10\xe1\x39\x12$\n\x1fk_EMsgDOTAFriendRecruitsRequest\x10\xe2\x39\x12%\n k_EMsgDOTAFriendRecruitsResponse\x10\xe3\x39\x12/\n*k_EMsgDOTAFriendRecruitInviteAcceptDecline\x10\xe4\x39\x12\'\n\"k_EMsgGCPartyLeaderWatchGamePrompt\x10\xe5\x39\x12#\n\x1ek_EMsgDOTAFrostivusTimeElapsed\x10\xe6\x39\x12#\n\x1ek_EMsgDOTALiveLeagueGameUpdate\x10\xea\x39\x12\x1e\n\x19k_EMsgDOTAChatGetUserList\x10\xeb\x39\x12&\n!k_EMsgDOTAChatGetUserListResponse\x10\xec\x39\x12#\n\x1ek_EMsgGCCompendiumSetSelection\x10\xed\x39\x12\"\n\x1dk_EMsgGCCompendiumDataRequest\x10\xee\x39\x12#\n\x1ek_EMsgGCCompendiumDataResponse\x10\xef\x39\x12$\n\x1fk_EMsgDOTAGetPlayerMatchHistory\x10\xf0\x39\x12,\n\'k_EMsgDOTAGetPlayerMatchHistoryResponse\x10\xf1\x39\x12$\n\x1fk_EMsgGCToGCMatchmakingAddParty\x10\xf2\x39\x12\'\n\"k_EMsgGCToGCMatchmakingRemoveParty\x10\xf3\x39\x12,\n\'k_EMsgGCToGCMatchmakingRemoveAllParties\x10\xf4\x39\x12&\n!k_EMsgGCToGCMatchmakingMatchFound\x10\xf5\x39\x12+\n&k_EMsgGCToGCUpdateMatchManagementStats\x10\xf6\x39\x12\'\n\"k_EMsgGCToGCUpdateMatchmakingStats\x10\xf7\x39\x12 \n\x1bk_EMsgGCToServerPingRequest\x10\xf8\x39\x12!\n\x1ck_EMsgGCToServerPingResponse\x10\xf9\x39\x12#\n\x1ek_EMsgGCToServerConsoleCommand\x10\xfa\x39\x12)\n$k_EMsgGCToGCUpdateLiveLeagueGameInfo\x10\xfc\x39\x12\x19\n\x14k_EMsgGCMakeOffering\x10\xff\x39\x12\x1d\n\x18k_EMsgGCRequestOfferings\x10\x80:\x12%\n k_EMsgGCRequestOfferingsResponse\x10\x81:\x12#\n\x1ek_EMsgGCToGCProcessMatchLeaver\x10\x82:\x12!\n\x1ck_EMsgGCNotificationsRequest\x10\x83:\x12\"\n\x1dk_EMsgGCNotificationsResponse\x10\x84:\x12#\n\x1ek_EMsgGCToGCModifyNotification\x10\x85:\x12$\n\x1fk_EMsgGCToGCSetNewNotifications\x10\x86:\x12!\n\x1ck_EMsgGCToGCSetIsLeagueAdmin\x10\x87:\x12\x1d\n\x18k_EMsgGCLeagueAdminState\x10\x88:\x12%\n k_EMsgGCToGCSendLeagueAdminState\x10\x89:\x12\x1c\n\x17k_EMsgGCLeagueAdminList\x10\x8a:\x12)\n$k_EMsgGCNotificationsMarkReadRequest\x10\x8b:\x12\x1e\n\x19k_EMsgGCFantasyMessageAdd\x10\x8c:\x12#\n\x1ek_EMsgGCFantasyMessagesRequest\x10\x8d:\x12$\n\x1fk_EMsgGCFantasyMessagesResponse\x10\x8e:\x12+\n&k_EMsgGCFantasyScheduledMatchesRequest\x10\x8f:\x12,\n\'k_EMsgGCFantasyScheduledMatchesResponse\x10\x90:\x12\"\n\x1dk_EMsgGCToGCGrantLeagueAccess\x10\x91:\x12\x1c\n\x17k_EMsgGCEventGameCreate\x10\x93:\x12*\n%k_EMsgGCPerfectWorldUserLookupRequest\x10\x94:\x12+\n&k_EMsgGCPerfectWorldUserLookupResponse\x10\x95:\x12\x1f\n\x1ak_EMsgGCFantasyRemoveOwner\x10\x98:\x12\'\n\"k_EMsgGCFantasyRemoveOwnerResponse\x10\x99:\x12(\n#k_EMsgGCRequestBatchPlayerResources\x10\x9a:\x12\x30\n+k_EMsgGCRequestBatchPlayerResourcesResponse\x10\x9b:\x12\"\n\x1dk_EMsgGCToGCSendUpdateLeagues\x10\x9c:\x12+\n&k_EMsgGCCompendiumSetSelectionResponse\x10\x9d:\x12\x1e\n\x19k_EMsgGCPlayerInfoRequest\x10\x9e:\x12\x17\n\x12k_EMsgGCPlayerInfo\x10\x9f:\x12\x1d\n\x18k_EMsgGCPlayerInfoSubmit\x10\xa0:\x12%\n k_EMsgGCPlayerInfoSubmitResponse\x10\xa1:\x12 \n\x1bk_EMsgGCToGCGetAccountLevel\x10\xa2:\x12(\n#k_EMsgGCToGCGetAccountLevelResponse\x10\xa3:\x12\"\n\x1dk_EMsgGCToGCGetAccountPartner\x10\xa4:\x12*\n%k_EMsgGCToGCGetAccountPartnerResponse\x10\xa5:\x12\"\n\x1dk_EMsgGCToGCGetAccountProfile\x10\xa6:\x12*\n%k_EMsgGCToGCGetAccountProfileResponse\x10\xa7:\x12(\n#k_EMsgDOTAGetWeekendTourneySchedule\x10\xa8:\x12%\n k_EMsgDOTAWeekendTourneySchedule\x10\xa9:\x12+\n&k_EMsgGCJoinableCustomGameModesRequest\x10\xaa:\x12,\n\'k_EMsgGCJoinableCustomGameModesResponse\x10\xab:\x12)\n$k_EMsgGCJoinableCustomLobbiesRequest\x10\xac:\x12*\n%k_EMsgGCJoinableCustomLobbiesResponse\x10\xad:\x12!\n\x1ck_EMsgGCQuickJoinCustomLobby\x10\xae:\x12)\n$k_EMsgGCQuickJoinCustomLobbyResponse\x10\xaf:\x12&\n!k_EMsgGCToGCGrantEventPointAction\x10\xb0:\x12\x1f\n\x1ak_EMsgServerGetEventPoints\x10\xb1:\x12\'\n\"k_EMsgServerGetEventPointsResponse\x10\xb2:\x12&\n!k_EMsgServerGrantSurveyPermission\x10\xb3:\x12.\n)k_EMsgServerGrantSurveyPermissionResponse\x10\xb4:\x12$\n\x1fk_EMsgClientProvideSurveyResult\x10\xb5:\x12\'\n\"k_EMsgGCToGCSetCompendiumSelection\x10\xb6:\x12#\n\x1ek_EMsgGCToGCUpdateTI4HeroQuest\x10\xb8:\x12\"\n\x1dk_EMsgGCCompendiumDataChanged\x10\xb9:\x12\'\n\"k_EMsgDOTAFantasyLeagueFindRequest\x10\xba:\x12(\n#k_EMsgDOTAFantasyLeagueFindResponse\x10\xbb:\x12\x19\n\x14k_EMsgGCHasItemQuery\x10\xbc:\x12\x1c\n\x17k_EMsgGCHasItemResponse\x10\xbd:\x12!\n\x1ck_EMsgGCConsumeFantasyTicket\x10\xbe:\x12(\n#k_EMsgGCConsumeFantasyTicketFailure\x10\xbf:\x12)\n$k_EMsgGCToGCGrantEventPointActionMsg\x10\xc0:\x12&\n!k_EMsgClientToGCTrackDialogResult\x10\xc1:\x12&\n!k_EMsgGCFantasyLeaveLeagueRequest\x10\xc2:\x12\'\n\"k_EMsgGCFantasyLeaveLeagueResponse\x10\xc3:\x12(\n#k_EMsgGCToGCGetCompendiumSelections\x10\xc4:\x12\x30\n+k_EMsgGCToGCGetCompendiumSelectionsResponse\x10\xc5:\x12)\n$k_EMsgServerToGCMatchConnectionStats\x10\xc6:\x12\'\n\"k_EMsgGCToClientTournamentItemDrop\x10\xc7:\x12$\n\x1fk_EMsgSQLDelayedGrantLeagueDrop\x10\xc8:\x12\'\n\"k_EMsgServerGCUpdateSpectatorCount\x10\xc9:\x12-\n(k_EMsgGCFantasyPlayerScoreDetailsRequest\x10\xcb:\x12.\n)k_EMsgGCFantasyPlayerScoreDetailsResponse\x10\xcc:\x12\x1f\n\x1ak_EMsgGCToGCEmoticonUnlock\x10\xcd:\x12\x1b\n\x16k_EMsgSignOutDraftInfo\x10\xce:\x12(\n#k_EMsgClientToGCEmoticonDataRequest\x10\xcf:\x12!\n\x1ck_EMsgGCToClientEmoticonData\x10\xd0:\x12?\n:k_EMsgGCPracticeLobbyToggleBroadcastChannelCameramanStatus\x10\xd1:\x12,\n\'k_EMsgGCToGCCreateWeekendTourneyRequest\x10\xd2:\x12-\n(k_EMsgGCToGCCreateWeekendTourneyResponse\x10\xd3:\x12(\n#k_EMsgClientToGCSetAdditionalEquips\x10\xd9:\x12(\n#k_EMsgClientToGCGetAdditionalEquips\x10\xda:\x12\x30\n+k_EMsgClientToGCGetAdditionalEquipsResponse\x10\xdb:\x12(\n#k_EMsgServerToGCGetAdditionalEquips\x10\xdc:\x12\x30\n+k_EMsgServerToGCGetAdditionalEquipsResponse\x10\xdd:\x12\x19\n\x14k_EMsgDOTARedeemItem\x10\xde:\x12!\n\x1ck_EMsgDOTARedeemItemResponse\x10\xdf:\x12(\n#k_EMsgSQLGCToGCGrantAllHeroProgress\x10\xe0:\x12\'\n\"k_EMsgClientToGCGetAllHeroProgress\x10\xe1:\x12/\n*k_EMsgClientToGCGetAllHeroProgressResponse\x10\xe2:\x12#\n\x1ek_EMsgGCToGCGetServerForClient\x10\xe3:\x12+\n&k_EMsgGCToGCGetServerForClientResponse\x10\xe4:\x12*\n%k_EMsgSQLProcessTournamentGameOutcome\x10\xe5:\x12\"\n\x1dk_EMsgSQLGrantTrophyToAccount\x10\xe6:\x12\"\n\x1dk_EMsgClientToGCGetTrophyList\x10\xe7:\x12*\n%k_EMsgClientToGCGetTrophyListResponse\x10\xe8:\x12\"\n\x1dk_EMsgGCToClientTrophyAwarded\x10\xe9:\x12 \n\x1bk_EMsgGCGameBotMatchSignOut\x10\xea:\x12\x31\n,k_EMsgGCGameBotMatchSignOutPermissionRequest\x10\xeb:\x12\x19\n\x14k_EMsgSignOutBotInfo\x10\xec:\x12#\n\x1ek_EMsgGCToGCUpdateProfileCards\x10\xed:\x12#\n\x1ek_EMsgClientToGCGetProfileCard\x10\xee:\x12+\n&k_EMsgClientToGCGetProfileCardResponse\x10\xef:\x12#\n\x1ek_EMsgServerToGCGetProfileCard\x10\xf0:\x12+\n&k_EMsgServerToGCGetProfileCardResponse\x10\xf1:\x12(\n#k_EMsgClientToGCSetProfileCardSlots\x10\xf2:\x12\'\n\"k_EMsgGCToClientProfileCardUpdated\x10\xf3:\x12\'\n\"k_EMsgServerToGCVictoryPredictions\x10\xf4:\x12-\n(k_EMsgClientToGCMarkNotificationListRead\x10\xf6:\x12)\n$k_EMsgGCToClientNewNotificationAdded\x10\xf7:\x12\'\n\"k_EMsgServerToGCSuspiciousActivity\x10\xf8:\x12&\n!k_EMsgSignOutCommunicationSummary\x10\xf9:\x12+\n&k_EMsgServerToGCRequestStatus_Response\x10\xfa:\x12%\n k_EMsgClientToGCCreateHeroStatue\x10\xfb:\x12+\n&k_EMsgGCToClientHeroStatueCreateResult\x10\xfc:\x12&\n!k_EMsgGCGCToLANServerRelayConnect\x10\xfd:\x12\'\n\"k_EMsgServerToGCGetIngameEventData\x10\xff:\x12/\n*k_EMsgGCToGCUpdateIngameEventDataBroadcast\x10\x80;\x12-\n(k_EMsgGCToServerIngameEventData_OraclePA\x10\x81;\x12(\n#k_EMsgServerToGCReportKillSummaries\x10\x82;\x12$\n\x1fk_EMsgGCToGCReportKillSummaries\x10\x83;\x12\'\n\"k_EMsgGCToGCUpdateAssassinMinigame\x10\x84;\x12&\n!k_EMsgGCToGCFantasySetMatchLeague\x10\x85;\x12*\n%k_EMsgClientToGCRecordCompendiumStats\x10\x86;\x12(\n#k_EMsgGCItemEditorRequestLeagueInfo\x10\x87;\x12)\n$k_EMsgGCItemEditorLeagueInfoResponse\x10\x88;\x12(\n#k_EMsgGCToGCUpdatePlayerPredictions\x10\x89;\x12%\n k_EMsgGCToServerPredictionResult\x10\x8a;\x12\x30\n+k_EMsgServerToGCSignoutAwardAdditionalDrops\x10\x8b;\x12,\n\'k_EMsgGCToGCSignoutAwardAdditionalDrops\x10\x8c;\x12\'\n\"k_EMsgGCToClientEventStatusChanged\x10\x8d;\x12\x1d\n\x18k_EMsgGCHasItemDefsQuery\x10\x8e;\x12 \n\x1bk_EMsgGCHasItemDefsResponse\x10\x8f;\x12,\n\'k_EMsgGCToGCReplayMonitorValidateReplay\x10\x91;\x12\x1b\n\x16k_EMsgLobbyEventPoints\x10\x94;\x12%\n k_EMsgGCToGCGetCustomGameTickets\x10\x95;\x12-\n(k_EMsgGCToGCGetCustomGameTicketsResponse\x10\x96;\x12!\n\x1ck_EMsgGCToGCCustomGamePlayed\x10\x98;\x12\'\n\"k_EMsgGCToGCGrantEventPointsToUser\x10\x99;\x12)\n$k_EMsgGCToGCSetEventMMPanicFlushTime\x10\x9a;\x12 \n\x1bk_EMsgGameserverCrashReport\x10\x9b;\x12(\n#k_EMsgGameserverCrashReportResponse\x10\x9c;\x12(\n#k_EMsgGCToClientSteamDatagramTicket\x10\x9d;\x12$\n\x1fk_EMsgGCToGCGrantEventOwnership\x10\x9e;\x12(\n#k_EMsgGCToGCSendAccountsEventPoints\x10\x9f;\x12*\n%k_EMsgClientToGCRerollPlayerChallenge\x10\xa0;\x12*\n%k_EMsgServerToGCRerollPlayerChallenge\x10\xa1;\x12*\n%k_EMsgGCRerollPlayerChallengeResponse\x10\xa2;\x12\'\n\"k_EMsgSignOutUpdatePlayerChallenge\x10\xa3;\x12#\n\x1ek_EMsgClientToGCSetPartyLeader\x10\xa4;\x12\'\n\"k_EMsgClientToGCCancelPartyInvites\x10\xa5;\x12$\n\x1fk_EMsgGCToGCMasterReloadAccount\x10\xa6;\x12-\n(k_EMsgSQLGrantLeagueMatchToTicketHolders\x10\xa8;\x12\x30\n+k_EMsgClientToGCSetAdditionalEquipsResponse\x10\xa9;\x12)\n$k_EMsgGCToGCEmoticonUnlockNoRollback\x10\xaa;\x12%\n k_EMsgGCToGCGetCompendiumFanfare\x10\xab;\x12$\n\x1fk_EMsgServerToGCHoldEventPoints\x10\xac;\x12(\n#k_EMsgSignOutReleaseEventPointHolds\x10\xad;\x12#\n\x1ek_EMsgGCToGCChatNewUserSession\x10\xae;\x12$\n\x1fk_EMsgClientToGCGetLeagueSeries\x10\xaf;\x12,\n\'k_EMsgClientToGCGetLeagueSeriesResponse\x10\xb0;\x12/\n*k_EMsgSQLGCToGCSignoutUpdateLeagueSchedule\x10\xb1;\x12*\n%k_EMsgGCToServerUpdateBroadcastCheers\x10\xb2;\x12%\n k_EMsgClientToGCApplyGemCombiner\x10\xb3;\x12+\n&k_EMsgClientToGCDOTACreateStaticRecipe\x10\xb4;\x12\x33\n.k_EMsgClientToGCDOTACreateStaticRecipeResponse\x10\xb5;\x12$\n\x1fk_EMsgClientToGCGetAllHeroOrder\x10\xb6;\x12,\n\'k_EMsgClientToGCGetAllHeroOrderResponse\x10\xb7;\x12$\n\x1fk_EMsgSQLGCToGCGrantBadgePoints\x10\xb8;\x12&\n!k_EMsgGCToGCGetAccountMatchStatus\x10\xb9;\x12.\n)k_EMsgGCToGCGetAccountMatchStatusResponse\x10\xba;\x12-\n(k_EMsgGCToGCCheckOwnsEntireEmoticonRange\x10\xbb;\x12\x35\n0k_EMsgGCToGCCheckOwnsEntireEmoticonRangeResponse\x10\xbc;\x12\x1d\n\x18k_EMsgGCDev_GrantWarKill\x10\xc1>\x12%\n k_EMsgServerToGCLockCharmTrading\x10\xc4>\x12\'\n\"k_EMsgClientToGCPlayerStatsRequest\x10\xc6>\x12(\n#k_EMsgGCToClientPlayerStatsResponse\x10\xc7>\x12#\n\x1ek_EMsgGCClearPracticeLobbyTeam\x10\xc8>\x12)\n$k_EMsgClientToGCFindTopSourceTVGames\x10\xc9>\x12\x31\n,k_EMsgGCToClientFindTopSourceTVGamesResponse\x10\xca>\x12\x16\n\x11k_EMsgGCLobbyList\x10\xcb>\x12\x1e\n\x19k_EMsgGCLobbyListResponse\x10\xcc>\x12$\n\x1fk_EMsgGCPlayerStatsMatchSignOut\x10\xcd>\x12\x31\n,k_EMsgClientToGCCustomGamePlayerCountRequest\x10\xce>\x12\x32\n-k_EMsgGCToClientCustomGamePlayerCountResponse\x10\xcf>\x12\x31\n,k_EMsgClientToGCSocialFeedPostCommentRequest\x10\xd0>\x12\x32\n-k_EMsgGCToClientSocialFeedPostCommentResponse\x10\xd1>\x12\x34\n/k_EMsgClientToGCCustomGamesFriendsPlayedRequest\x10\xd2>\x12\x35\n0k_EMsgGCToClientCustomGamesFriendsPlayedResponse\x10\xd3>\x12\x33\n.k_EMsgClientToGCFriendsPlayedCustomGameRequest\x10\xd4>\x12\x34\n/k_EMsgGCToClientFriendsPlayedCustomGameResponse\x10\xd5>\x12*\n%k_EMsgClientToGCFeaturedHeroesRequest\x10\xd6>\x12+\n&k_EMsgGCToClientFeaturedHeroesResponse\x10\xd7>\x12\x1f\n\x1ak_EMsgGCTopCustomGamesList\x10\xd8>\x12\x32\n-k_EMsgClientToGCSocialMatchPostCommentRequest\x10\xd9>\x12\x33\n.k_EMsgGCToClientSocialMatchPostCommentResponse\x10\xda>\x12.\n)k_EMsgClientToGCSocialMatchDetailsRequest\x10\xdb>\x12/\n*k_EMsgGCToClientSocialMatchDetailsResponse\x10\xdc>\x12!\n\x1ck_EMsgClientToGCSetPartyOpen\x10\xdd>\x12%\n k_EMsgClientToGCMergePartyInvite\x10\xde>\x12*\n%k_EMsgGCToClientMergeGroupInviteReply\x10\xdf>\x12\'\n\"k_EMsgClientToGCMergePartyResponse\x10\xe0>\x12,\n\'k_EMsgGCToClientMergePartyResponseReply\x10\xe1>\x12(\n#k_EMsgClientToGCGetProfileCardStats\x10\xe2>\x12\x30\n+k_EMsgClientToGCGetProfileCardStatsResponse\x10\xe3>\x12,\n\'k_EMsgClientToGCTopLeagueMatchesRequest\x10\xe4>\x12,\n\'k_EMsgClientToGCTopFriendMatchesRequest\x10\xe5>\x12,\n\'k_EMsgGCToClientProfileCardStatsUpdated\x10\xe8>\x12\"\n\x1dk_EMsgServerToGCRealtimeStats\x10\xe9>\x12+\n&k_EMsgGCToServerRealtimeStatsStartStop\x10\xea>\x12%\n k_EMsgGCToGCGetServersForClients\x10\xed>\x12-\n(k_EMsgGCToGCGetServersForClientsResponse\x10\xee>\x12&\n!k_EMsgGCPracticeLobbyKickFromTeam\x10\xef>\x12!\n\x1ck_EMsgDOTAChatGetMemberCount\x10\xf0>\x12)\n$k_EMsgDOTAChatGetMemberCountResponse\x10\xf1>\x12\x31\n,k_EMsgClientToGCSocialFeedPostMessageRequest\x10\xf2>\x12\x32\n-k_EMsgGCToClientSocialFeedPostMessageResponse\x10\xf3>\x12/\n*k_EMsgCustomGameListenServerStartedLoading\x10\xf4>\x12*\n%k_EMsgCustomGameClientFinishedLoading\x10\xf5>\x12/\n*k_EMsgGCPracticeLobbyCloseBroadcastChannel\x10\xf6>\x12&\n!k_EMsgGCStartFindingMatchResponse\x10\xf7>\x12$\n\x1fk_EMsgSQLGCToGCGrantAccountFlag\x10\xf9>\x12 \n\x1bk_EMsgGCToGCGetAccountFlags\x10\xfa>\x12(\n#k_EMsgGCToGCGetAccountFlagsResponse\x10\xfb>\x12\x1c\n\x17k_EMsgSignOutWagerStats\x10\xfc>\x12-\n(k_EMsgGCToClientTopLeagueMatchesResponse\x10\xfd>\x12-\n(k_EMsgGCToClientTopFriendMatchesResponse\x10\xfe>\x12*\n%k_EMsgClientToGCMatchesMinimalRequest\x10\xff>\x12+\n&k_EMsgClientToGCMatchesMinimalResponse\x10\x80?\x12&\n!k_EMsgGCToGCGetProfileBadgePoints\x10\x81?\x12.\n)k_EMsgGCToGCGetProfileBadgePointsResponse\x10\x82?\x12\'\n\"k_EMsgGCToClientChatRegionsEnabled\x10\x83?\x12\x1d\n\x18k_EMsgClientToGCPingData\x10\x84?\x12(\n#k_EMsgServerToGCMatchDetailsRequest\x10\x85?\x12)\n$k_EMsgGCToServerMatchDetailsResponse\x10\x86?\x12%\n k_EMsgGCToGCEnsureAccountInParty\x10\x87?\x12-\n(k_EMsgGCToGCEnsureAccountInPartyResponse\x10\x88?\x12&\n!k_EMsgClientToGCGetProfileTickets\x10\x89?\x12.\n)k_EMsgClientToGCGetProfileTicketsResponse\x10\x8a?\x12\'\n\"k_EMsgGCToClientMatchGroupsVersion\x10\x8b?\x12$\n\x1fk_EMsgClientToGCH264Unsupported\x10\x8c?\x12\'\n\"k_EMsgClientToGCRequestH264Support\x10\x8d?\x12%\n k_EMsgClientToGCGetQuestProgress\x10\x8e?\x12-\n(k_EMsgClientToGCGetQuestProgressResponse\x10\x8f?\x12\x19\n\x14k_EMsgSignOutXPCoins\x10\x90?\x12#\n\x1ek_EMsgGCToClientMatchSignedOut\x10\x91?\x12 \n\x1bk_EMsgGCGetHeroStatsHistory\x10\x92?\x12(\n#k_EMsgGCGetHeroStatsHistoryResponse\x10\x93?\x12&\n!k_EMsgClientToGCPrivateChatInvite\x10\x94?\x12$\n\x1fk_EMsgClientToGCPrivateChatKick\x10\x98?\x12\'\n\"k_EMsgClientToGCPrivateChatPromote\x10\x99?\x12&\n!k_EMsgClientToGCPrivateChatDemote\x10\x9a?\x12(\n#k_EMsgGCToClientPrivateChatResponse\x10\x9b?\x12+\n&k_EMsgClientToGCPrivateChatInfoRequest\x10\x9c?\x12,\n\'k_EMsgGCToClientPrivateChatInfoResponse\x10\x9d?\x12\x32\n-k_EMsgClientToGCLatestConductScorecardRequest\x10\x9f?\x12+\n&k_EMsgClientToGCLatestConductScorecard\x10\xa0?\x12!\n\x1ck_EMsgServerToGCPostMatchTip\x10\xa1?\x12)\n$k_EMsgServerToGCPostMatchTipResponse\x10\xa2?\x12$\n\x1fk_EMsgClientToGCWageringRequest\x10\xa3?\x12%\n k_EMsgGCToClientWageringResponse\x10\xa4?\x12 \n\x1bk_EMsgClientToGCMysteryItem\x10\xa5?\x12(\n#k_EMsgGCToClientMysteryItemResponse\x10\xa6?\x12&\n!k_EMsgClientToGCEventGoalsRequest\x10\xa7?\x12\'\n\"k_EMsgClientToGCEventGoalsResponse\x10\xa8?\x12&\n!k_EMsgClientToGCLeaguePredictions\x10\xaa?\x12.\n)k_EMsgGCToClientLeaguePredictionsResponse\x10\xab?\x12(\n#k_EMsgGCToGCLeaguePredictionsUpdate\x10\xac?\x12\'\n\"k_EMsgClientToGCSuspiciousActivity\x10\xad?\x12&\n!k_EMsgGCToGCAddUserToPostGameChat\x10\xae?\x12)\n$k_EMsgClientToGCHasPlayerVotedForMVP\x10\xaf?\x12\x31\n,k_EMsgClientToGCHasPlayerVotedForMVPResponse\x10\xb0?\x12\x1f\n\x1ak_EMsgClientToGCVoteForMVP\x10\xb1?\x12\'\n\"k_EMsgClientToGCVoteForMVPResponse\x10\xb2?\x12\"\n\x1dk_EMsgGCToGCGetEventOwnership\x10\xb3?\x12*\n%k_EMsgGCToGCGetEventOwnershipResponse\x10\xb4?\x12\x33\n.k_EMsgGCToClientAutomatedTournamentStateChange\x10\xb5?\x12\'\n\"k_EMsgClientToGCWeekendTourneyOpts\x10\xb6?\x12/\n*k_EMsgClientToGCWeekendTourneyOptsResponse\x10\xb7?\x12(\n#k_EMsgClientToGCWeekendTourneyLeave\x10\xb8?\x12\x30\n+k_EMsgClientToGCWeekendTourneyLeaveResponse\x10\xb9?\x12)\n$k_EMsgClientToGCTeammateStatsRequest\x10\xbc?\x12*\n%k_EMsgClientToGCTeammateStatsResponse\x10\xbd?\x12\'\n\"k_EMsgClientToGCGetGiftPermissions\x10\xbe?\x12/\n*k_EMsgClientToGCGetGiftPermissionsResponse\x10\xbf?\x12\"\n\x1dk_EMsgClientToGCVoteForArcana\x10\xc0?\x12*\n%k_EMsgClientToGCVoteForArcanaResponse\x10\xc1?\x12\x30\n+k_EMsgClientToGCRequestArcanaVotesRemaining\x10\xc2?\x12\x38\n3k_EMsgClientToGCRequestArcanaVotesRemainingResponse\x10\xc3?\x12&\n!k_EMsgGCTransferTeamAdminResponse\x10\xc4?\x12\x1a\n\x15k_EMsgGCChangeTeamSub\x10\xc5?\x12\"\n\x1dk_EMsgGCChangeTeamSubResponse\x10\xc6?\x12\x1d\n\x18k_EMsgGCToClientTeamInfo\x10\xc7?\x12\x1e\n\x19k_EMsgGCToClientTeamsInfo\x10\xc8?\x12&\n!k_EMsgClientToGCMyTeamInfoRequest\x10\xc9?\x12)\n$k_EMsgClientToGCRequestEventPointLog\x10\xca?\x12\x31\n,k_EMsgClientToGCRequestEventPointLogResponse\x10\xcb?\x12$\n\x1fk_EMsgClientToGCPublishUserStat\x10\xcc?\x12\"\n\x1dk_EMsgGCToGCSignoutSpendWager\x10\xcd?\x12!\n\x1ck_EMsgClientToGCRedeemReward\x10\xce?\x12)\n$k_EMsgGCToClientRedeemRewardResponse\x10\xcf?\x12\x1f\n\x1ak_EMsgGCSubmitLobbyMVPVote\x10\xd0?\x12\'\n\"k_EMsgGCSubmitLobbyMVPVoteResponse\x10\xd1?\x12.\n)k_EMsgClientToGCRequestLinaPlaysRemaining\x10\xd2?\x12\x36\n1k_EMsgClientToGCRequestLinaPlaysRemainingResponse\x10\xd3?\x12*\n%k_EMsgClientToGCRequestLinaGameResult\x10\xd4?\x12\x32\n-k_EMsgClientToGCRequestLinaGameResultResponse\x10\xd5?\x12\'\n\"k_EMsgSignOutCommunityGoalProgress\x10\xd6?\x12,\n\'k_EMsgGCToClientLobbyMVPNotifyRecipient\x10\xd7?\x12$\n\x1fk_EMsgGCToClientLobbyMVPAwarded\x10\xd8?\x12)\n$k_EMsgGCToClientQuestProgressUpdated\x10\xd9?\x12#\n\x1ek_EMsgGCToClientWageringUpdate\x10\xda?\x12&\n!k_EMsgGCToClientArcanaVotesUpdate\x10\xdb?\x12\'\n\"k_EMsgClientToGCAddTI6TreeProgress\x10\xdc?\x12-\n(k_EMsgClientToGCSetSpectatorLobbyDetails\x10\xdd?\x12\x35\n0k_EMsgClientToGCSetSpectatorLobbyDetailsResponse\x10\xde?\x12)\n$k_EMsgClientToGCCreateSpectatorLobby\x10\xdf?\x12\x31\n,k_EMsgClientToGCCreateSpectatorLobbyResponse\x10\xe0?\x12\'\n\"k_EMsgClientToGCSpectatorLobbyList\x10\xe1?\x12/\n*k_EMsgClientToGCSpectatorLobbyListResponse\x10\xe2?\x12$\n\x1fk_EMsgSpectatorLobbyGameDetails\x10\xe3?\x12\x35\n0k_EMsgServerToGCStartCompendiumInGamePredictions\x10\xe4?\x12\x33\n.k_EMsgServerToGCEndCompendiumInGamePredictions\x10\xe5?\x12\x36\n1k_EMsgServerToGCCompendiumInGamePredictionResults\x10\xe6?\x12:\n5k_EMsgServerToGCCloseCompendiumInGamePredictionVoting\x10\xe7?\x12\'\n\"k_EMsgClientToGCOpenPlayerCardPack\x10\xe8?\x12/\n*k_EMsgClientToGCOpenPlayerCardPackResponse\x10\xe9?\x12\x35\n0k_EMsgClientToGCSelectCompendiumInGamePrediction\x10\xea?\x12=\n8k_EMsgClientToGCSelectCompendiumInGamePredictionResponse\x10\xeb?\x12\x31\n,k_EMsgClientToGCWeekendTourneyGetPlayerStats\x10\xec?\x12\x39\n4k_EMsgClientToGCWeekendTourneyGetPlayerStatsResponse\x10\xed?\x12&\n!k_EMsgClientToGCRecyclePlayerCard\x10\xee?\x12.\n)k_EMsgClientToGCRecyclePlayerCardResponse\x10\xef?\x12)\n$k_EMsgClientToGCCreatePlayerCardPack\x10\xf0?\x12\x31\n,k_EMsgClientToGCCreatePlayerCardPackResponse\x10\xf1?\x12/\n*k_EMsgClientToGCGetPlayerCardRosterRequest\x10\xf2?\x12\x30\n+k_EMsgClientToGCGetPlayerCardRosterResponse\x10\xf3?\x12/\n*k_EMsgClientToGCSetPlayerCardRosterRequest\x10\xf4?\x12\x30\n+k_EMsgClientToGCSetPlayerCardRosterResponse\x10\xf5?\x12=\n8k_EMsgServerToGCStartCompendiumInGamePredictionsResponse\x10\xf6?\x12\x42\n=k_EMsgServerToGCCloseCompendiumInGamePredictionVotingResponse\x10\xf7?\x12;\n6k_EMsgServerToGCEndCompendiumInGamePredictionsResponse\x10\xf8?\x12>\n9k_EMsgServerToGCCompendiumInGamePredictionResultsResponse\x10\xf9?\x12 \n\x1bk_EMsgLobbyBattleCupVictory\x10\xfa?\x12\"\n\x1dk_EMsgGCGetPlayerCardItemInfo\x10\xfb?\x12*\n%k_EMsgGCGetPlayerCardItemInfoResponse\x10\xfc?\x12/\n*k_EMsgClientToGCRequestSteamDatagramTicket\x10\xfd?\x12\x37\n2k_EMsgClientToGCRequestSteamDatagramTicketResponse\x10\xfe?\x12,\n\'k_EMsgGCToClientBattlePassRollupRequest\x10\xff?\x12-\n(k_EMsgGCToClientBattlePassRollupResponse\x10\x80@\x12/\n*k_EMsgClientToGCTransferSeasonalMMRRequest\x10\x81@\x12\x30\n+k_EMsgClientToGCTransferSeasonalMMRResponse\x10\x82@\x12+\n&k_EMsgGCToGCPublicChatCommunicationBan\x10\x83@\x12+\n&k_EMsgGCToGCUpdateAccountPublicChatBan\x10\x84@\x12!\n\x1ck_EMsgGCChatReportPublicSpam\x10\x85@\x12+\n&k_EMsgClientToGCSetPartyBuilderOptions\x10\x86@\x12\x33\n.k_EMsgClientToGCSetPartyBuilderOptionsResponse\x10\x87@\x12\x30\n+k_EMsgGCToClientBattlePassRollupListRequest\x10\x8d@\x12\x31\n,k_EMsgGCToClientBattlePassRollupListResponse\x10\x8e@\x12\x1e\n\x19k_EMsgDOTASetFavoriteTeam\x10\x8c@B\x05H\x01\x90\x01\x00')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_EDOTAGCMSG = _descriptor.EnumDescriptor(
  name='EDOTAGCMsg',
  full_name='EDOTAGCMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDOTABase', index=0, number=7000,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGeneralResponse', index=1, number=7001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGameMatchSignOut', index=2, number=7004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGameMatchSignOutResponse', index=3, number=7005,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCJoinChatChannel', index=4, number=7009,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCJoinChatChannelResponse', index=5, number=7010,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCOtherJoinedChannel', index=6, number=7013,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCOtherLeftChannel', index=7, number=7014,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCMatchHistoryList', index=8, number=7017,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCRequestStatus', index=9, number=7026,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGetRecentMatches', index=10, number=7027,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRecentMatchesResponse', index=11, number=7028,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStartFindingMatch', index=12, number=7033,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCConnectedPlayers', index=13, number=7034,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAbandonCurrentGame', index=14, number=7035,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStopFindingMatch', index=15, number=7036,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPracticeLobbyCreate', index=16, number=7038,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPracticeLobbyLeave', index=17, number=7040,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPracticeLobbyLaunch', index=18, number=7041,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPracticeLobbyList', index=19, number=7042,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPracticeLobbyListResponse', index=20, number=7043,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPracticeLobbyJoin', index=21, number=7044,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPracticeLobbySetDetails', index=22, number=7046,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPracticeLobbySetTeamSlot', index=23, number=7047,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCInitialQuestionnaireResponse', index=24, number=7049,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPracticeLobbyResponse', index=25, number=7055,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBroadcastNotification', index=26, number=7056,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLiveScoreboardUpdate', index=27, number=7057,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestChatChannelList', index=28, number=7060,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestChatChannelListResponse', index=29, number=7061,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestMatches', index=30, number=7064,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestMatchesResponse', index=31, number=7065,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestPlayerResources', index=32, number=7068,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestPlayerResourcesResponse', index=33, number=7069,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCReadyUp', index=34, number=7070,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCKickedFromMatchmakingQueue', index=35, number=7071,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLeaverDetected', index=36, number=7072,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSpectateFriendGame', index=37, number=7073,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSpectateFriendGameResponse', index=38, number=7074,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPlayerReports', index=39, number=7075,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCReportsRemainingRequest', index=40, number=7076,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCReportsRemainingResponse', index=41, number=7077,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSubmitPlayerReport', index=42, number=7078,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSubmitPlayerReportResponse', index=43, number=7079,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPracticeLobbyKick', index=44, number=7081,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCReportCountsRequest', index=45, number=7082,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCReportCountsResponse', index=46, number=7083,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestSaveGames', index=47, number=7084,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestSaveGamesServer', index=48, number=7085,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestSaveGamesResponse', index=49, number=7086,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLeaverDetectedResponse', index=50, number=7087,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPlayerFailedToConnect', index=51, number=7088,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGCToRelayConnect', index=52, number=7089,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGCToRelayConnectresponse', index=53, number=7090,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCWatchGame', index=54, number=7091,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCWatchGameResponse', index=55, number=7092,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBanStatusRequest', index=56, number=7093,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBanStatusResponse', index=57, number=7094,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCMatchDetailsRequest', index=58, number=7095,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCMatchDetailsResponse', index=59, number=7096,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCancelWatchGame', index=60, number=7097,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCProfileRequest', index=61, number=7098,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCProfileResponse', index=62, number=7099,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPopup', index=63, number=7102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDOTAClearNotifySuccessfulReport', index=64, number=7104,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFriendPracticeLobbyListRequest', index=65, number=7111,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFriendPracticeLobbyListResponse', index=66, number=7112,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPracticeLobbyJoinResponse', index=67, number=7113,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientEconNotification_Job', index=68, number=7114,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCreateTeam', index=69, number=7115,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCreateTeamResponse', index=70, number=7116,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTeamData', index=71, number=7121,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTeamInvite_InviterToGC', index=72, number=7122,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTeamInvite_GCImmediateResponseToInviter', index=73, number=7123,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTeamInvite_GCRequestToInvitee', index=74, number=7124,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTeamInvite_InviteeResponseToGC', index=75, number=7125,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTeamInvite_GCResponseToInviter', index=76, number=7126,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTeamInvite_GCResponseToInvitee', index=77, number=7127,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCKickTeamMember', index=78, number=7128,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCKickTeamMemberResponse', index=79, number=7129,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLeaveTeam', index=80, number=7130,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLeaveTeamResponse', index=81, number=7131,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSuggestTeamMatchmaking', index=82, number=7132,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPlayerHeroesFavoritesAdd', index=83, number=7133,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPlayerHeroesFavoritesRemove', index=84, number=7134,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetShowcaseHero', index=85, number=7141,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplyTeamToPracticeLobby', index=86, number=7142,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestInternatinalTicketEmail', index=87, number=7143,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTransferTeamAdmin', index=88, number=7144,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRequestLeagueInfo', index=89, number=7147,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgResponseLeagueInfo', index=90, number=7148,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPracticeLobbyJoinBroadcastChannel', index=91, number=7149,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_TournamentItemEvent', index=92, number=7150,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_TournamentItemEventResponse', index=93, number=7151,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCastMatchVote', index=94, number=7152,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCastMatchVoteResponse', index=95, number=7153,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRetrieveMatchVote', index=96, number=7154,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRetrieveMatchVoteResponse', index=97, number=7155,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgTeamFanfare', index=98, number=7156,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgResponseTeamFanfare', index=99, number=7157,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_GameServerUploadSaveGame', index=100, number=7158,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_GameServerSaveGameResult', index=101, number=7159,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_GameServerGetLoadGame', index=102, number=7160,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_GameServerGetLoadGameResult', index=103, number=7161,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCEditTeamDetails', index=104, number=7166,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCEditTeamDetailsResponse', index=105, number=7167,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCProTeamListRequest', index=106, number=7168,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCProTeamListResponse', index=107, number=7169,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCReadyUpStatus', index=108, number=7170,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHallOfFame', index=109, number=7171,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHallOfFameRequest', index=110, number=7172,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHallOfFameResponse', index=111, number=7173,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGenerateDiretidePrizeList', index=112, number=7174,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRewardDiretidePrizes', index=113, number=7176,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDiretidePrizesRewardedResponse', index=114, number=7177,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHalloweenHighScoreRequest', index=115, number=7178,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHalloweenHighScoreResponse', index=116, number=7179,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGenerateDiretidePrizeListResponse', index=117, number=7180,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePromoPagesRequest', index=118, number=7182,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePromoPagesResponse', index=119, number=7183,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCMatchCompleted', index=120, number=7186,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBalancedShuffleLobby', index=121, number=7188,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCCheckLeaguePermission', index=122, number=7189,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCCheckLeaguePermissionResponse', index=123, number=7190,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLeagueScheduleRequest', index=124, number=7191,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLeagueScheduleResponse', index=125, number=7192,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLeagueScheduleEdit', index=126, number=7193,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLeagueScheduleEditResponse', index=127, number=7194,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLeaguesInMonthRequest', index=128, number=7195,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLeaguesInMonthResponse', index=129, number=7196,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCMatchmakingStatsRequest', index=130, number=7197,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCMatchmakingStatsResponse', index=131, number=7198,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBotGameCreate', index=132, number=7199,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetMatchHistoryAccess', index=133, number=7200,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetMatchHistoryAccessResponse', index=134, number=7201,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUpgradeLeagueItem', index=135, number=7203,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUpgradeLeagueItemResponse', index=136, number=7204,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTeamMemberProfileRequest', index=137, number=7205,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCWatchDownloadedReplay', index=138, number=7206,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetMapLocationState', index=139, number=7207,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetMapLocationStateResponse', index=140, number=7208,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCResetMapLocations', index=141, number=7209,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCResetMapLocationsResponse', index=142, number=7210,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetFeaturedItems', index=143, number=7212,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFeaturedItems', index=144, number=7215,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRefreshPartnerAccountLink', index=145, number=7216,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientsRejoinChatChannels', index=146, number=7217,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetUserChatInfo', index=147, number=7218,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetUserChatInfoResponse', index=148, number=7219,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCLeaveAllChatChannels', index=149, number=7220,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdateAccountChatBan', index=150, number=7221,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildCreateRequest', index=151, number=7222,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildCreateResponse', index=152, number=7223,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildSetAccountRoleRequest', index=153, number=7224,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildSetAccountRoleResponse', index=154, number=7225,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestGuildData', index=155, number=7226,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildData', index=156, number=7227,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildInviteAccountRequest', index=157, number=7228,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildInviteAccountResponse', index=158, number=7229,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildCancelInviteRequest', index=159, number=7230,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildCancelInviteResponse', index=160, number=7231,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildUpdateDetailsRequest', index=161, number=7232,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildUpdateDetailsResponse', index=162, number=7233,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCCanInviteUserToTeam', index=163, number=7234,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCCanInviteUserToTeamResponse', index=164, number=7235,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetUserRank', index=165, number=7236,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetUserRankResponse', index=166, number=7237,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdateTeamStats', index=167, number=7240,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetTeamRank', index=168, number=7241,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetTeamRankResponse', index=169, number=7242,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPassportDataRequest', index=170, number=7248,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPassportDataResponse', index=171, number=7249,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNotInGuildData', index=172, number=7251,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildInviteData', index=173, number=7254,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetLeagueAdmin', index=174, number=7255,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetLeagueAdminResponse', index=175, number=7256,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestLeaguePrizePool', index=176, number=7258,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestLeaguePrizePoolResponse', index=177, number=7259,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdateOpenGuildPartyRequest', index=178, number=7261,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdateOpenGuildPartyResponse', index=179, number=7262,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCDestroyOpenGuildPartyRequest', index=180, number=7263,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCDestroyOpenGuildPartyResponse', index=181, number=7264,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildUpdateMessage', index=182, number=7265,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPartySetOpenGuildRequest', index=183, number=7266,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPartySetOpenGuildResponse', index=184, number=7267,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildOpenPartyRefresh', index=185, number=7268,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCJoinOpenGuildPartyRequest', index=186, number=7269,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCJoinOpenGuildPartyResponse', index=187, number=7270,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLeaveChatChannel', index=188, number=7272,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCChatMessage', index=189, number=7273,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGetHeroStandings', index=190, number=7274,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGetHeroStandingsResponse', index=191, number=7275,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildEditLogoRequest', index=192, number=7279,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildEditLogoResponse', index=193, number=7280,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildmatePracticeLobbyListRequest', index=194, number=7281,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGuildmatePracticeLobbyListResponse', index=195, number=7282,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemEditorReservationsRequest', index=196, number=7283,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemEditorReservationsResponse', index=197, number=7284,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemEditorReserveItemDef', index=198, number=7285,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemEditorReserveItemDefResponse', index=199, number=7286,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemEditorReleaseReservation', index=200, number=7287,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemEditorReleaseReservationResponse', index=201, number=7288,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRewardTutorialPrizes', index=202, number=7289,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLastHitChallengeHighScorePost', index=203, number=7290,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLastHitChallengeHighScoreRequest', index=204, number=7291,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLastHitChallengeHighScoreResponse', index=205, number=7292,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCreateFantasyLeagueRequest', index=206, number=7293,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCreateFantasyLeagueResponse', index=207, number=7294,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueInfoRequest', index=208, number=7297,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueInfoResponse', index=209, number=7298,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueInfo', index=210, number=7299,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCreateFantasyTeamRequest', index=211, number=7300,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCreateFantasyTeamResponse', index=212, number=7301,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCEditFantasyTeamRequest', index=213, number=7302,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCEditFantasyTeamResponse', index=214, number=7303,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamInfoRequestByFantasyLeagueID', index=215, number=7304,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamInfoRequestByOwnerAccountID', index=216, number=7305,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamInfoResponse', index=217, number=7306,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamInfo', index=218, number=7307,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLivePlayerStats', index=219, number=7308,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyFinalPlayerStats', index=220, number=7309,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyMatch', index=221, number=7310,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamScoreRequest', index=222, number=7312,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamScoreResponse', index=223, number=7313,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamStandingsRequest', index=224, number=7314,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamStandingsResponse', index=225, number=7315,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyPlayerScoreRequest', index=226, number=7316,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyPlayerScoreResponse', index=227, number=7317,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyPlayerStandingsRequest', index=228, number=7318,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyPlayerStandingsResponse', index=229, number=7319,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFlipLobbyTeams', index=230, number=7320,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCustomGameCreate', index=231, number=7321,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyPlayerInfoRequest', index=232, number=7322,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyPlayerInfoResponse', index=233, number=7323,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCProcessPlayerReportForTarget', index=234, number=7324,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCProcessReportSuccess', index=235, number=7325,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNotifyAccountFlagsChange', index=236, number=7326,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetProfilePrivacy', index=237, number=7327,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetProfilePrivacyResponse', index=238, number=7328,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSteamProfileRequest', index=239, number=7329,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSteamProfileRequestResponse', index=240, number=7330,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueCreateInfoRequest', index=241, number=7331,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueCreateInfoResponse', index=242, number=7332,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueInviteInfoRequest', index=243, number=7333,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueInviteInfoResponse', index=244, number=7334,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientIgnoredUser', index=245, number=7335,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueCreateRequest', index=246, number=7336,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueCreateResponse', index=247, number=7337,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamCreateRequest', index=248, number=7338,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamCreateResponse', index=249, number=7339,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueFriendJoinListRequest', index=250, number=7340,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueFriendJoinListResponse', index=251, number=7341,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientSuspended', index=252, number=7342,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPartyMemberSetCoach', index=253, number=7343,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueEditInvitesRequest', index=254, number=7344,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueEditInvitesResponse', index=255, number=7345,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPracticeLobbySetCoach', index=256, number=7346,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueEditInfoRequest', index=257, number=7347,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueEditInfoResponse', index=258, number=7348,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueDraftStatusRequest', index=259, number=7349,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueDraftStatus', index=260, number=7350,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueDraftPlayerRequest', index=261, number=7351,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueDraftPlayerResponse', index=262, number=7352,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueMatchupsRequest', index=263, number=7353,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeagueMatchupsResponse', index=264, number=7354,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamRosterSwapRequest', index=265, number=7355,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamRosterSwapResponse', index=266, number=7356,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamRosterRequest', index=267, number=7357,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamRosterResponse', index=268, number=7358,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNexonPartnerUpdate', index=269, number=7359,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCProcessPCBangRewardPoints', index=270, number=7360,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamRosterAddDropRequest', index=271, number=7361,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamRosterAddDropResponse', index=272, number=7362,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgPresentedClientTerminateDlg', index=273, number=7363,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyPlayerHisoricalStatsRequest', index=274, number=7364,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyPlayerHisoricalStatsResponse', index=275, number=7365,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPCBangTimedRewardMessage', index=276, number=7366,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLobbyUpdateBroadcastChannelInfo', index=277, number=7367,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamTradesRequest', index=278, number=7368,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamTradesResponse', index=279, number=7369,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamTradeCancelRequest', index=280, number=7370,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyTeamTradeCancelResponse', index=281, number=7371,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGrantTournamentItem', index=282, number=7372,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCProcessFantasyScheduledEvent', index=283, number=7373,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGrantPCBangRewardItem', index=284, number=7374,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpgradeTwitchViewerItems', index=285, number=7375,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetLiveMatchAffiliates', index=286, number=7376,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetLiveMatchAffiliatesResponse', index=287, number=7377,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdatePlayerPennantCounts', index=288, number=7378,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetPlayerPennantCounts', index=289, number=7379,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetPlayerPennantCountsResponse', index=290, number=7380,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGameMatchSignOutPermissionRequest', index=291, number=7381,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGameMatchSignOutPermissionResponse', index=292, number=7382,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAChatChannelMemberUpdate', index=293, number=7383,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAAwardEventPoints', index=294, number=7384,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTARedeemEventPrize', index=295, number=7385,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTARedeemEventPrizeResponse', index=296, number=7386,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAGetEventPoints', index=297, number=7387,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAGetEventPointsResponse', index=298, number=7388,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCSignoutAwardEventPoints', index=299, number=7390,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTASendFriendRecruits', index=300, number=7393,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAFriendRecruitsRequest', index=301, number=7394,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAFriendRecruitsResponse', index=302, number=7395,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAFriendRecruitInviteAcceptDecline', index=303, number=7396,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPartyLeaderWatchGamePrompt', index=304, number=7397,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAFrostivusTimeElapsed', index=305, number=7398,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTALiveLeagueGameUpdate', index=306, number=7402,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAChatGetUserList', index=307, number=7403,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAChatGetUserListResponse', index=308, number=7404,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCompendiumSetSelection', index=309, number=7405,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCompendiumDataRequest', index=310, number=7406,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCompendiumDataResponse', index=311, number=7407,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAGetPlayerMatchHistory', index=312, number=7408,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAGetPlayerMatchHistoryResponse', index=313, number=7409,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCMatchmakingAddParty', index=314, number=7410,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCMatchmakingRemoveParty', index=315, number=7411,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCMatchmakingRemoveAllParties', index=316, number=7412,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCMatchmakingMatchFound', index=317, number=7413,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdateMatchManagementStats', index=318, number=7414,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdateMatchmakingStats', index=319, number=7415,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToServerPingRequest', index=320, number=7416,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToServerPingResponse', index=321, number=7417,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToServerConsoleCommand', index=322, number=7418,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdateLiveLeagueGameInfo', index=323, number=7420,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCMakeOffering', index=324, number=7423,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestOfferings', index=325, number=7424,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestOfferingsResponse', index=326, number=7425,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCProcessMatchLeaver', index=327, number=7426,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNotificationsRequest', index=328, number=7427,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNotificationsResponse', index=329, number=7428,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCModifyNotification', index=330, number=7429,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCSetNewNotifications', index=331, number=7430,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCSetIsLeagueAdmin', index=332, number=7431,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLeagueAdminState', index=333, number=7432,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCSendLeagueAdminState', index=334, number=7433,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLeagueAdminList', index=335, number=7434,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNotificationsMarkReadRequest', index=336, number=7435,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyMessageAdd', index=337, number=7436,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyMessagesRequest', index=338, number=7437,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyMessagesResponse', index=339, number=7438,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyScheduledMatchesRequest', index=340, number=7439,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyScheduledMatchesResponse', index=341, number=7440,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGrantLeagueAccess', index=342, number=7441,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCEventGameCreate', index=343, number=7443,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPerfectWorldUserLookupRequest', index=344, number=7444,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPerfectWorldUserLookupResponse', index=345, number=7445,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyRemoveOwner', index=346, number=7448,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyRemoveOwnerResponse', index=347, number=7449,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestBatchPlayerResources', index=348, number=7450,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestBatchPlayerResourcesResponse', index=349, number=7451,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCSendUpdateLeagues', index=350, number=7452,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCompendiumSetSelectionResponse', index=351, number=7453,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPlayerInfoRequest', index=352, number=7454,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPlayerInfo', index=353, number=7455,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPlayerInfoSubmit', index=354, number=7456,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPlayerInfoSubmitResponse', index=355, number=7457,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetAccountLevel', index=356, number=7458,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetAccountLevelResponse', index=357, number=7459,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetAccountPartner', index=358, number=7460,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetAccountPartnerResponse', index=359, number=7461,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetAccountProfile', index=360, number=7462,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetAccountProfileResponse', index=361, number=7463,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAGetWeekendTourneySchedule', index=362, number=7464,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAWeekendTourneySchedule', index=363, number=7465,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCJoinableCustomGameModesRequest', index=364, number=7466,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCJoinableCustomGameModesResponse', index=365, number=7467,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCJoinableCustomLobbiesRequest', index=366, number=7468,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCJoinableCustomLobbiesResponse', index=367, number=7469,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCQuickJoinCustomLobby', index=368, number=7470,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCQuickJoinCustomLobbyResponse', index=369, number=7471,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGrantEventPointAction', index=370, number=7472,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerGetEventPoints', index=371, number=7473,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerGetEventPointsResponse', index=372, number=7474,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerGrantSurveyPermission', index=373, number=7475,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerGrantSurveyPermissionResponse', index=374, number=7476,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientProvideSurveyResult', index=375, number=7477,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCSetCompendiumSelection', index=376, number=7478,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdateTI4HeroQuest', index=377, number=7480,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCompendiumDataChanged', index=378, number=7481,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAFantasyLeagueFindRequest', index=379, number=7482,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAFantasyLeagueFindResponse', index=380, number=7483,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHasItemQuery', index=381, number=7484,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHasItemResponse', index=382, number=7485,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCConsumeFantasyTicket', index=383, number=7486,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCConsumeFantasyTicketFailure', index=384, number=7487,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGrantEventPointActionMsg', index=385, number=7488,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCTrackDialogResult', index=386, number=7489,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeaveLeagueRequest', index=387, number=7490,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyLeaveLeagueResponse', index=388, number=7491,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetCompendiumSelections', index=389, number=7492,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetCompendiumSelectionsResponse', index=390, number=7493,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCMatchConnectionStats', index=391, number=7494,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientTournamentItemDrop', index=392, number=7495,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSQLDelayedGrantLeagueDrop', index=393, number=7496,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerGCUpdateSpectatorCount', index=394, number=7497,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyPlayerScoreDetailsRequest', index=395, number=7499,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFantasyPlayerScoreDetailsResponse', index=396, number=7500,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCEmoticonUnlock', index=397, number=7501,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSignOutDraftInfo', index=398, number=7502,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCEmoticonDataRequest', index=399, number=7503,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientEmoticonData', index=400, number=7504,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPracticeLobbyToggleBroadcastChannelCameramanStatus', index=401, number=7505,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCCreateWeekendTourneyRequest', index=402, number=7506,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCCreateWeekendTourneyResponse', index=403, number=7507,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSetAdditionalEquips', index=404, number=7513,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetAdditionalEquips', index=405, number=7514,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetAdditionalEquipsResponse', index=406, number=7515,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCGetAdditionalEquips', index=407, number=7516,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCGetAdditionalEquipsResponse', index=408, number=7517,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTARedeemItem', index=409, number=7518,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTARedeemItemResponse', index=410, number=7519,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSQLGCToGCGrantAllHeroProgress', index=411, number=7520,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetAllHeroProgress', index=412, number=7521,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetAllHeroProgressResponse', index=413, number=7522,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetServerForClient', index=414, number=7523,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetServerForClientResponse', index=415, number=7524,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSQLProcessTournamentGameOutcome', index=416, number=7525,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSQLGrantTrophyToAccount', index=417, number=7526,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetTrophyList', index=418, number=7527,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetTrophyListResponse', index=419, number=7528,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientTrophyAwarded', index=420, number=7529,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGameBotMatchSignOut', index=421, number=7530,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGameBotMatchSignOutPermissionRequest', index=422, number=7531,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSignOutBotInfo', index=423, number=7532,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdateProfileCards', index=424, number=7533,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetProfileCard', index=425, number=7534,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetProfileCardResponse', index=426, number=7535,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCGetProfileCard', index=427, number=7536,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCGetProfileCardResponse', index=428, number=7537,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSetProfileCardSlots', index=429, number=7538,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientProfileCardUpdated', index=430, number=7539,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCVictoryPredictions', index=431, number=7540,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCMarkNotificationListRead', index=432, number=7542,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientNewNotificationAdded', index=433, number=7543,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCSuspiciousActivity', index=434, number=7544,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSignOutCommunicationSummary', index=435, number=7545,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCRequestStatus_Response', index=436, number=7546,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCCreateHeroStatue', index=437, number=7547,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientHeroStatueCreateResult', index=438, number=7548,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGCToLANServerRelayConnect', index=439, number=7549,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCGetIngameEventData', index=440, number=7551,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdateIngameEventDataBroadcast', index=441, number=7552,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToServerIngameEventData_OraclePA', index=442, number=7553,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCReportKillSummaries', index=443, number=7554,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCReportKillSummaries', index=444, number=7555,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdateAssassinMinigame', index=445, number=7556,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCFantasySetMatchLeague', index=446, number=7557,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRecordCompendiumStats', index=447, number=7558,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemEditorRequestLeagueInfo', index=448, number=7559,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemEditorLeagueInfoResponse', index=449, number=7560,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdatePlayerPredictions', index=450, number=7561,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToServerPredictionResult', index=451, number=7562,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCSignoutAwardAdditionalDrops', index=452, number=7563,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCSignoutAwardAdditionalDrops', index=453, number=7564,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientEventStatusChanged', index=454, number=7565,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHasItemDefsQuery', index=455, number=7566,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCHasItemDefsResponse', index=456, number=7567,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCReplayMonitorValidateReplay', index=457, number=7569,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLobbyEventPoints', index=458, number=7572,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetCustomGameTickets', index=459, number=7573,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetCustomGameTicketsResponse', index=460, number=7574,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCCustomGamePlayed', index=461, number=7576,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGrantEventPointsToUser', index=462, number=7577,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCSetEventMMPanicFlushTime', index=463, number=7578,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGameserverCrashReport', index=464, number=7579,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGameserverCrashReportResponse', index=465, number=7580,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientSteamDatagramTicket', index=466, number=7581,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGrantEventOwnership', index=467, number=7582,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCSendAccountsEventPoints', index=468, number=7583,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRerollPlayerChallenge', index=469, number=7584,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCRerollPlayerChallenge', index=470, number=7585,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRerollPlayerChallengeResponse', index=471, number=7586,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSignOutUpdatePlayerChallenge', index=472, number=7587,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSetPartyLeader', index=473, number=7588,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCCancelPartyInvites', index=474, number=7589,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCMasterReloadAccount', index=475, number=7590,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSQLGrantLeagueMatchToTicketHolders', index=476, number=7592,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSetAdditionalEquipsResponse', index=477, number=7593,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCEmoticonUnlockNoRollback', index=478, number=7594,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetCompendiumFanfare', index=479, number=7595,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCHoldEventPoints', index=480, number=7596,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSignOutReleaseEventPointHolds', index=481, number=7597,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCChatNewUserSession', index=482, number=7598,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetLeagueSeries', index=483, number=7599,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetLeagueSeriesResponse', index=484, number=7600,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSQLGCToGCSignoutUpdateLeagueSchedule', index=485, number=7601,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToServerUpdateBroadcastCheers', index=486, number=7602,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCApplyGemCombiner', index=487, number=7603,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCDOTACreateStaticRecipe', index=488, number=7604,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCDOTACreateStaticRecipeResponse', index=489, number=7605,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetAllHeroOrder', index=490, number=7606,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetAllHeroOrderResponse', index=491, number=7607,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSQLGCToGCGrantBadgePoints', index=492, number=7608,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetAccountMatchStatus', index=493, number=7609,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetAccountMatchStatusResponse', index=494, number=7610,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCCheckOwnsEntireEmoticonRange', index=495, number=7611,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCCheckOwnsEntireEmoticonRangeResponse', index=496, number=7612,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDev_GrantWarKill', index=497, number=8001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCLockCharmTrading', index=498, number=8004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCPlayerStatsRequest', index=499, number=8006,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientPlayerStatsResponse', index=500, number=8007,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClearPracticeLobbyTeam', index=501, number=8008,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCFindTopSourceTVGames', index=502, number=8009,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientFindTopSourceTVGamesResponse', index=503, number=8010,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLobbyList', index=504, number=8011,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLobbyListResponse', index=505, number=8012,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPlayerStatsMatchSignOut', index=506, number=8013,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCCustomGamePlayerCountRequest', index=507, number=8014,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientCustomGamePlayerCountResponse', index=508, number=8015,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSocialFeedPostCommentRequest', index=509, number=8016,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientSocialFeedPostCommentResponse', index=510, number=8017,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCCustomGamesFriendsPlayedRequest', index=511, number=8018,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientCustomGamesFriendsPlayedResponse', index=512, number=8019,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCFriendsPlayedCustomGameRequest', index=513, number=8020,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientFriendsPlayedCustomGameResponse', index=514, number=8021,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCFeaturedHeroesRequest', index=515, number=8022,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientFeaturedHeroesResponse', index=516, number=8023,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTopCustomGamesList', index=517, number=8024,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSocialMatchPostCommentRequest', index=518, number=8025,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientSocialMatchPostCommentResponse', index=519, number=8026,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSocialMatchDetailsRequest', index=520, number=8027,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientSocialMatchDetailsResponse', index=521, number=8028,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSetPartyOpen', index=522, number=8029,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCMergePartyInvite', index=523, number=8030,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientMergeGroupInviteReply', index=524, number=8031,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCMergePartyResponse', index=525, number=8032,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientMergePartyResponseReply', index=526, number=8033,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetProfileCardStats', index=527, number=8034,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetProfileCardStatsResponse', index=528, number=8035,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCTopLeagueMatchesRequest', index=529, number=8036,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCTopFriendMatchesRequest', index=530, number=8037,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientProfileCardStatsUpdated', index=531, number=8040,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCRealtimeStats', index=532, number=8041,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToServerRealtimeStatsStartStop', index=533, number=8042,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetServersForClients', index=534, number=8045,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetServersForClientsResponse', index=535, number=8046,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPracticeLobbyKickFromTeam', index=536, number=8047,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAChatGetMemberCount', index=537, number=8048,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTAChatGetMemberCountResponse', index=538, number=8049,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSocialFeedPostMessageRequest', index=539, number=8050,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientSocialFeedPostMessageResponse', index=540, number=8051,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCustomGameListenServerStartedLoading', index=541, number=8052,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgCustomGameClientFinishedLoading', index=542, number=8053,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPracticeLobbyCloseBroadcastChannel', index=543, number=8054,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStartFindingMatchResponse', index=544, number=8055,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSQLGCToGCGrantAccountFlag', index=545, number=8057,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetAccountFlags', index=546, number=8058,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetAccountFlagsResponse', index=547, number=8059,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSignOutWagerStats', index=548, number=8060,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientTopLeagueMatchesResponse', index=549, number=8061,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientTopFriendMatchesResponse', index=550, number=8062,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCMatchesMinimalRequest', index=551, number=8063,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCMatchesMinimalResponse', index=552, number=8064,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetProfileBadgePoints', index=553, number=8065,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetProfileBadgePointsResponse', index=554, number=8066,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientChatRegionsEnabled', index=555, number=8067,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCPingData', index=556, number=8068,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCMatchDetailsRequest', index=557, number=8069,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToServerMatchDetailsResponse', index=558, number=8070,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCEnsureAccountInParty', index=559, number=8071,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCEnsureAccountInPartyResponse', index=560, number=8072,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetProfileTickets', index=561, number=8073,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetProfileTicketsResponse', index=562, number=8074,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientMatchGroupsVersion', index=563, number=8075,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCH264Unsupported', index=564, number=8076,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRequestH264Support', index=565, number=8077,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetQuestProgress', index=566, number=8078,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetQuestProgressResponse', index=567, number=8079,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSignOutXPCoins', index=568, number=8080,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientMatchSignedOut', index=569, number=8081,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGetHeroStatsHistory', index=570, number=8082,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGetHeroStatsHistoryResponse', index=571, number=8083,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCPrivateChatInvite', index=572, number=8084,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCPrivateChatKick', index=573, number=8088,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCPrivateChatPromote', index=574, number=8089,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCPrivateChatDemote', index=575, number=8090,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientPrivateChatResponse', index=576, number=8091,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCPrivateChatInfoRequest', index=577, number=8092,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientPrivateChatInfoResponse', index=578, number=8093,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCLatestConductScorecardRequest', index=579, number=8095,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCLatestConductScorecard', index=580, number=8096,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCPostMatchTip', index=581, number=8097,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCPostMatchTipResponse', index=582, number=8098,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCWageringRequest', index=583, number=8099,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientWageringResponse', index=584, number=8100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCMysteryItem', index=585, number=8101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientMysteryItemResponse', index=586, number=8102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCEventGoalsRequest', index=587, number=8103,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCEventGoalsResponse', index=588, number=8104,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCLeaguePredictions', index=589, number=8106,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientLeaguePredictionsResponse', index=590, number=8107,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCLeaguePredictionsUpdate', index=591, number=8108,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSuspiciousActivity', index=592, number=8109,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCAddUserToPostGameChat', index=593, number=8110,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCHasPlayerVotedForMVP', index=594, number=8111,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCHasPlayerVotedForMVPResponse', index=595, number=8112,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCVoteForMVP', index=596, number=8113,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCVoteForMVPResponse', index=597, number=8114,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetEventOwnership', index=598, number=8115,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetEventOwnershipResponse', index=599, number=8116,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientAutomatedTournamentStateChange', index=600, number=8117,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCWeekendTourneyOpts', index=601, number=8118,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCWeekendTourneyOptsResponse', index=602, number=8119,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCWeekendTourneyLeave', index=603, number=8120,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCWeekendTourneyLeaveResponse', index=604, number=8121,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCTeammateStatsRequest', index=605, number=8124,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCTeammateStatsResponse', index=606, number=8125,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetGiftPermissions', index=607, number=8126,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetGiftPermissionsResponse', index=608, number=8127,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCVoteForArcana', index=609, number=8128,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCVoteForArcanaResponse', index=610, number=8129,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRequestArcanaVotesRemaining', index=611, number=8130,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRequestArcanaVotesRemainingResponse', index=612, number=8131,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTransferTeamAdminResponse', index=613, number=8132,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCChangeTeamSub', index=614, number=8133,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCChangeTeamSubResponse', index=615, number=8134,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientTeamInfo', index=616, number=8135,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientTeamsInfo', index=617, number=8136,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCMyTeamInfoRequest', index=618, number=8137,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRequestEventPointLog', index=619, number=8138,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRequestEventPointLogResponse', index=620, number=8139,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCPublishUserStat', index=621, number=8140,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCSignoutSpendWager', index=622, number=8141,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRedeemReward', index=623, number=8142,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientRedeemRewardResponse', index=624, number=8143,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSubmitLobbyMVPVote', index=625, number=8144,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSubmitLobbyMVPVoteResponse', index=626, number=8145,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRequestLinaPlaysRemaining', index=627, number=8146,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRequestLinaPlaysRemainingResponse', index=628, number=8147,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRequestLinaGameResult', index=629, number=8148,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRequestLinaGameResultResponse', index=630, number=8149,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSignOutCommunityGoalProgress', index=631, number=8150,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientLobbyMVPNotifyRecipient', index=632, number=8151,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientLobbyMVPAwarded', index=633, number=8152,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientQuestProgressUpdated', index=634, number=8153,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientWageringUpdate', index=635, number=8154,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientArcanaVotesUpdate', index=636, number=8155,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCAddTI6TreeProgress', index=637, number=8156,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSetSpectatorLobbyDetails', index=638, number=8157,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSetSpectatorLobbyDetailsResponse', index=639, number=8158,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCCreateSpectatorLobby', index=640, number=8159,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCCreateSpectatorLobbyResponse', index=641, number=8160,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSpectatorLobbyList', index=642, number=8161,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSpectatorLobbyListResponse', index=643, number=8162,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSpectatorLobbyGameDetails', index=644, number=8163,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCStartCompendiumInGamePredictions', index=645, number=8164,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCEndCompendiumInGamePredictions', index=646, number=8165,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCCompendiumInGamePredictionResults', index=647, number=8166,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCCloseCompendiumInGamePredictionVoting', index=648, number=8167,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCOpenPlayerCardPack', index=649, number=8168,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCOpenPlayerCardPackResponse', index=650, number=8169,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSelectCompendiumInGamePrediction', index=651, number=8170,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSelectCompendiumInGamePredictionResponse', index=652, number=8171,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCWeekendTourneyGetPlayerStats', index=653, number=8172,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCWeekendTourneyGetPlayerStatsResponse', index=654, number=8173,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRecyclePlayerCard', index=655, number=8174,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRecyclePlayerCardResponse', index=656, number=8175,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCCreatePlayerCardPack', index=657, number=8176,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCCreatePlayerCardPackResponse', index=658, number=8177,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetPlayerCardRosterRequest', index=659, number=8178,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCGetPlayerCardRosterResponse', index=660, number=8179,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSetPlayerCardRosterRequest', index=661, number=8180,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSetPlayerCardRosterResponse', index=662, number=8181,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCStartCompendiumInGamePredictionsResponse', index=663, number=8182,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCCloseCompendiumInGamePredictionVotingResponse', index=664, number=8183,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCEndCompendiumInGamePredictionsResponse', index=665, number=8184,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgServerToGCCompendiumInGamePredictionResultsResponse', index=666, number=8185,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgLobbyBattleCupVictory', index=667, number=8186,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGetPlayerCardItemInfo', index=668, number=8187,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGetPlayerCardItemInfoResponse', index=669, number=8188,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRequestSteamDatagramTicket', index=670, number=8189,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRequestSteamDatagramTicketResponse', index=671, number=8190,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientBattlePassRollupRequest', index=672, number=8191,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientBattlePassRollupResponse', index=673, number=8192,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCTransferSeasonalMMRRequest', index=674, number=8193,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCTransferSeasonalMMRResponse', index=675, number=8194,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCPublicChatCommunicationBan', index=676, number=8195,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdateAccountPublicChatBan', index=677, number=8196,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCChatReportPublicSpam', index=678, number=8197,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSetPartyBuilderOptions', index=679, number=8198,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSetPartyBuilderOptionsResponse', index=680, number=8199,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientBattlePassRollupListRequest', index=681, number=8205,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientBattlePassRollupListResponse', index=682, number=8206,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgDOTASetFavoriteTeam', index=683, number=8204,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=33,
  serialized_end=27638,
)
_sym_db.RegisterEnumDescriptor(_EDOTAGCMSG)

EDOTAGCMsg = enum_type_wrapper.EnumTypeWrapper(_EDOTAGCMSG)
k_EMsgGCDOTABase = 7000
k_EMsgGCGeneralResponse = 7001
k_EMsgGCGameMatchSignOut = 7004
k_EMsgGCGameMatchSignOutResponse = 7005
k_EMsgGCJoinChatChannel = 7009
k_EMsgGCJoinChatChannelResponse = 7010
k_EMsgGCOtherJoinedChannel = 7013
k_EMsgGCOtherLeftChannel = 7014
k_EMsgGCMatchHistoryList = 7017
k_EMsgServerToGCRequestStatus = 7026
k_EMsgGCGetRecentMatches = 7027
k_EMsgGCRecentMatchesResponse = 7028
k_EMsgGCStartFindingMatch = 7033
k_EMsgGCConnectedPlayers = 7034
k_EMsgGCAbandonCurrentGame = 7035
k_EMsgGCStopFindingMatch = 7036
k_EMsgGCPracticeLobbyCreate = 7038
k_EMsgGCPracticeLobbyLeave = 7040
k_EMsgGCPracticeLobbyLaunch = 7041
k_EMsgGCPracticeLobbyList = 7042
k_EMsgGCPracticeLobbyListResponse = 7043
k_EMsgGCPracticeLobbyJoin = 7044
k_EMsgGCPracticeLobbySetDetails = 7046
k_EMsgGCPracticeLobbySetTeamSlot = 7047
k_EMsgGCInitialQuestionnaireResponse = 7049
k_EMsgGCPracticeLobbyResponse = 7055
k_EMsgGCBroadcastNotification = 7056
k_EMsgGCLiveScoreboardUpdate = 7057
k_EMsgGCRequestChatChannelList = 7060
k_EMsgGCRequestChatChannelListResponse = 7061
k_EMsgGCRequestMatches = 7064
k_EMsgGCRequestMatchesResponse = 7065
k_EMsgGCRequestPlayerResources = 7068
k_EMsgGCRequestPlayerResourcesResponse = 7069
k_EMsgGCReadyUp = 7070
k_EMsgGCKickedFromMatchmakingQueue = 7071
k_EMsgGCLeaverDetected = 7072
k_EMsgGCSpectateFriendGame = 7073
k_EMsgGCSpectateFriendGameResponse = 7074
k_EMsgGCPlayerReports = 7075
k_EMsgGCReportsRemainingRequest = 7076
k_EMsgGCReportsRemainingResponse = 7077
k_EMsgGCSubmitPlayerReport = 7078
k_EMsgGCSubmitPlayerReportResponse = 7079
k_EMsgGCPracticeLobbyKick = 7081
k_EMsgGCReportCountsRequest = 7082
k_EMsgGCReportCountsResponse = 7083
k_EMsgGCRequestSaveGames = 7084
k_EMsgGCRequestSaveGamesServer = 7085
k_EMsgGCRequestSaveGamesResponse = 7086
k_EMsgGCLeaverDetectedResponse = 7087
k_EMsgGCPlayerFailedToConnect = 7088
k_EMsgGCGCToRelayConnect = 7089
k_EMsgGCGCToRelayConnectresponse = 7090
k_EMsgGCWatchGame = 7091
k_EMsgGCWatchGameResponse = 7092
k_EMsgGCBanStatusRequest = 7093
k_EMsgGCBanStatusResponse = 7094
k_EMsgGCMatchDetailsRequest = 7095
k_EMsgGCMatchDetailsResponse = 7096
k_EMsgGCCancelWatchGame = 7097
k_EMsgGCProfileRequest = 7098
k_EMsgGCProfileResponse = 7099
k_EMsgGCPopup = 7102
k_EMsgGCDOTAClearNotifySuccessfulReport = 7104
k_EMsgGCFriendPracticeLobbyListRequest = 7111
k_EMsgGCFriendPracticeLobbyListResponse = 7112
k_EMsgGCPracticeLobbyJoinResponse = 7113
k_EMsgClientEconNotification_Job = 7114
k_EMsgGCCreateTeam = 7115
k_EMsgGCCreateTeamResponse = 7116
k_EMsgGCTeamData = 7121
k_EMsgGCTeamInvite_InviterToGC = 7122
k_EMsgGCTeamInvite_GCImmediateResponseToInviter = 7123
k_EMsgGCTeamInvite_GCRequestToInvitee = 7124
k_EMsgGCTeamInvite_InviteeResponseToGC = 7125
k_EMsgGCTeamInvite_GCResponseToInviter = 7126
k_EMsgGCTeamInvite_GCResponseToInvitee = 7127
k_EMsgGCKickTeamMember = 7128
k_EMsgGCKickTeamMemberResponse = 7129
k_EMsgGCLeaveTeam = 7130
k_EMsgGCLeaveTeamResponse = 7131
k_EMsgGCSuggestTeamMatchmaking = 7132
k_EMsgGCPlayerHeroesFavoritesAdd = 7133
k_EMsgGCPlayerHeroesFavoritesRemove = 7134
k_EMsgGCSetShowcaseHero = 7141
k_EMsgGCApplyTeamToPracticeLobby = 7142
k_EMsgGCRequestInternatinalTicketEmail = 7143
k_EMsgGCTransferTeamAdmin = 7144
k_EMsgRequestLeagueInfo = 7147
k_EMsgResponseLeagueInfo = 7148
k_EMsgGCPracticeLobbyJoinBroadcastChannel = 7149
k_EMsgGC_TournamentItemEvent = 7150
k_EMsgGC_TournamentItemEventResponse = 7151
k_EMsgCastMatchVote = 7152
k_EMsgCastMatchVoteResponse = 7153
k_EMsgRetrieveMatchVote = 7154
k_EMsgRetrieveMatchVoteResponse = 7155
k_EMsgTeamFanfare = 7156
k_EMsgResponseTeamFanfare = 7157
k_EMsgGC_GameServerUploadSaveGame = 7158
k_EMsgGC_GameServerSaveGameResult = 7159
k_EMsgGC_GameServerGetLoadGame = 7160
k_EMsgGC_GameServerGetLoadGameResult = 7161
k_EMsgGCEditTeamDetails = 7166
k_EMsgGCEditTeamDetailsResponse = 7167
k_EMsgGCProTeamListRequest = 7168
k_EMsgGCProTeamListResponse = 7169
k_EMsgGCReadyUpStatus = 7170
k_EMsgGCHallOfFame = 7171
k_EMsgGCHallOfFameRequest = 7172
k_EMsgGCHallOfFameResponse = 7173
k_EMsgGCGenerateDiretidePrizeList = 7174
k_EMsgGCRewardDiretidePrizes = 7176
k_EMsgGCDiretidePrizesRewardedResponse = 7177
k_EMsgGCHalloweenHighScoreRequest = 7178
k_EMsgGCHalloweenHighScoreResponse = 7179
k_EMsgGCGenerateDiretidePrizeListResponse = 7180
k_EMsgGCStorePromoPagesRequest = 7182
k_EMsgGCStorePromoPagesResponse = 7183
k_EMsgGCToGCMatchCompleted = 7186
k_EMsgGCBalancedShuffleLobby = 7188
k_EMsgGCToGCCheckLeaguePermission = 7189
k_EMsgGCToGCCheckLeaguePermissionResponse = 7190
k_EMsgGCLeagueScheduleRequest = 7191
k_EMsgGCLeagueScheduleResponse = 7192
k_EMsgGCLeagueScheduleEdit = 7193
k_EMsgGCLeagueScheduleEditResponse = 7194
k_EMsgGCLeaguesInMonthRequest = 7195
k_EMsgGCLeaguesInMonthResponse = 7196
k_EMsgGCMatchmakingStatsRequest = 7197
k_EMsgGCMatchmakingStatsResponse = 7198
k_EMsgGCBotGameCreate = 7199
k_EMsgGCSetMatchHistoryAccess = 7200
k_EMsgGCSetMatchHistoryAccessResponse = 7201
k_EMsgUpgradeLeagueItem = 7203
k_EMsgUpgradeLeagueItemResponse = 7204
k_EMsgGCTeamMemberProfileRequest = 7205
k_EMsgGCWatchDownloadedReplay = 7206
k_EMsgGCSetMapLocationState = 7207
k_EMsgGCSetMapLocationStateResponse = 7208
k_EMsgGCResetMapLocations = 7209
k_EMsgGCResetMapLocationsResponse = 7210
k_EMsgGCSetFeaturedItems = 7212
k_EMsgGCFeaturedItems = 7215
k_EMsgRefreshPartnerAccountLink = 7216
k_EMsgClientsRejoinChatChannels = 7217
k_EMsgGCToGCGetUserChatInfo = 7218
k_EMsgGCToGCGetUserChatInfoResponse = 7219
k_EMsgGCToGCLeaveAllChatChannels = 7220
k_EMsgGCToGCUpdateAccountChatBan = 7221
k_EMsgGCGuildCreateRequest = 7222
k_EMsgGCGuildCreateResponse = 7223
k_EMsgGCGuildSetAccountRoleRequest = 7224
k_EMsgGCGuildSetAccountRoleResponse = 7225
k_EMsgGCRequestGuildData = 7226
k_EMsgGCGuildData = 7227
k_EMsgGCGuildInviteAccountRequest = 7228
k_EMsgGCGuildInviteAccountResponse = 7229
k_EMsgGCGuildCancelInviteRequest = 7230
k_EMsgGCGuildCancelInviteResponse = 7231
k_EMsgGCGuildUpdateDetailsRequest = 7232
k_EMsgGCGuildUpdateDetailsResponse = 7233
k_EMsgGCToGCCanInviteUserToTeam = 7234
k_EMsgGCToGCCanInviteUserToTeamResponse = 7235
k_EMsgGCToGCGetUserRank = 7236
k_EMsgGCToGCGetUserRankResponse = 7237
k_EMsgGCToGCUpdateTeamStats = 7240
k_EMsgGCToGCGetTeamRank = 7241
k_EMsgGCToGCGetTeamRankResponse = 7242
k_EMsgGCPassportDataRequest = 7248
k_EMsgGCPassportDataResponse = 7249
k_EMsgGCNotInGuildData = 7251
k_EMsgGCGuildInviteData = 7254
k_EMsgGCToGCGetLeagueAdmin = 7255
k_EMsgGCToGCGetLeagueAdminResponse = 7256
k_EMsgGCRequestLeaguePrizePool = 7258
k_EMsgGCRequestLeaguePrizePoolResponse = 7259
k_EMsgGCToGCUpdateOpenGuildPartyRequest = 7261
k_EMsgGCToGCUpdateOpenGuildPartyResponse = 7262
k_EMsgGCToGCDestroyOpenGuildPartyRequest = 7263
k_EMsgGCToGCDestroyOpenGuildPartyResponse = 7264
k_EMsgGCGuildUpdateMessage = 7265
k_EMsgGCPartySetOpenGuildRequest = 7266
k_EMsgGCPartySetOpenGuildResponse = 7267
k_EMsgGCGuildOpenPartyRefresh = 7268
k_EMsgGCJoinOpenGuildPartyRequest = 7269
k_EMsgGCJoinOpenGuildPartyResponse = 7270
k_EMsgGCLeaveChatChannel = 7272
k_EMsgGCChatMessage = 7273
k_EMsgGCGetHeroStandings = 7274
k_EMsgGCGetHeroStandingsResponse = 7275
k_EMsgGCGuildEditLogoRequest = 7279
k_EMsgGCGuildEditLogoResponse = 7280
k_EMsgGCGuildmatePracticeLobbyListRequest = 7281
k_EMsgGCGuildmatePracticeLobbyListResponse = 7282
k_EMsgGCItemEditorReservationsRequest = 7283
k_EMsgGCItemEditorReservationsResponse = 7284
k_EMsgGCItemEditorReserveItemDef = 7285
k_EMsgGCItemEditorReserveItemDefResponse = 7286
k_EMsgGCItemEditorReleaseReservation = 7287
k_EMsgGCItemEditorReleaseReservationResponse = 7288
k_EMsgGCRewardTutorialPrizes = 7289
k_EMsgGCLastHitChallengeHighScorePost = 7290
k_EMsgGCLastHitChallengeHighScoreRequest = 7291
k_EMsgGCLastHitChallengeHighScoreResponse = 7292
k_EMsgGCCreateFantasyLeagueRequest = 7293
k_EMsgGCCreateFantasyLeagueResponse = 7294
k_EMsgGCFantasyLeagueInfoRequest = 7297
k_EMsgGCFantasyLeagueInfoResponse = 7298
k_EMsgGCFantasyLeagueInfo = 7299
k_EMsgGCCreateFantasyTeamRequest = 7300
k_EMsgGCCreateFantasyTeamResponse = 7301
k_EMsgGCEditFantasyTeamRequest = 7302
k_EMsgGCEditFantasyTeamResponse = 7303
k_EMsgGCFantasyTeamInfoRequestByFantasyLeagueID = 7304
k_EMsgGCFantasyTeamInfoRequestByOwnerAccountID = 7305
k_EMsgGCFantasyTeamInfoResponse = 7306
k_EMsgGCFantasyTeamInfo = 7307
k_EMsgGCFantasyLivePlayerStats = 7308
k_EMsgGCFantasyFinalPlayerStats = 7309
k_EMsgGCFantasyMatch = 7310
k_EMsgGCFantasyTeamScoreRequest = 7312
k_EMsgGCFantasyTeamScoreResponse = 7313
k_EMsgGCFantasyTeamStandingsRequest = 7314
k_EMsgGCFantasyTeamStandingsResponse = 7315
k_EMsgGCFantasyPlayerScoreRequest = 7316
k_EMsgGCFantasyPlayerScoreResponse = 7317
k_EMsgGCFantasyPlayerStandingsRequest = 7318
k_EMsgGCFantasyPlayerStandingsResponse = 7319
k_EMsgGCFlipLobbyTeams = 7320
k_EMsgGCCustomGameCreate = 7321
k_EMsgGCFantasyPlayerInfoRequest = 7322
k_EMsgGCFantasyPlayerInfoResponse = 7323
k_EMsgGCToGCProcessPlayerReportForTarget = 7324
k_EMsgGCToGCProcessReportSuccess = 7325
k_EMsgGCNotifyAccountFlagsChange = 7326
k_EMsgGCSetProfilePrivacy = 7327
k_EMsgGCSetProfilePrivacyResponse = 7328
k_EMsgGCSteamProfileRequest = 7329
k_EMsgGCSteamProfileRequestResponse = 7330
k_EMsgGCFantasyLeagueCreateInfoRequest = 7331
k_EMsgGCFantasyLeagueCreateInfoResponse = 7332
k_EMsgGCFantasyLeagueInviteInfoRequest = 7333
k_EMsgGCFantasyLeagueInviteInfoResponse = 7334
k_EMsgGCClientIgnoredUser = 7335
k_EMsgGCFantasyLeagueCreateRequest = 7336
k_EMsgGCFantasyLeagueCreateResponse = 7337
k_EMsgGCFantasyTeamCreateRequest = 7338
k_EMsgGCFantasyTeamCreateResponse = 7339
k_EMsgGCFantasyLeagueFriendJoinListRequest = 7340
k_EMsgGCFantasyLeagueFriendJoinListResponse = 7341
k_EMsgGCClientSuspended = 7342
k_EMsgGCPartyMemberSetCoach = 7343
k_EMsgGCFantasyLeagueEditInvitesRequest = 7344
k_EMsgGCFantasyLeagueEditInvitesResponse = 7345
k_EMsgGCPracticeLobbySetCoach = 7346
k_EMsgGCFantasyLeagueEditInfoRequest = 7347
k_EMsgGCFantasyLeagueEditInfoResponse = 7348
k_EMsgGCFantasyLeagueDraftStatusRequest = 7349
k_EMsgGCFantasyLeagueDraftStatus = 7350
k_EMsgGCFantasyLeagueDraftPlayerRequest = 7351
k_EMsgGCFantasyLeagueDraftPlayerResponse = 7352
k_EMsgGCFantasyLeagueMatchupsRequest = 7353
k_EMsgGCFantasyLeagueMatchupsResponse = 7354
k_EMsgGCFantasyTeamRosterSwapRequest = 7355
k_EMsgGCFantasyTeamRosterSwapResponse = 7356
k_EMsgGCFantasyTeamRosterRequest = 7357
k_EMsgGCFantasyTeamRosterResponse = 7358
k_EMsgGCNexonPartnerUpdate = 7359
k_EMsgGCToGCProcessPCBangRewardPoints = 7360
k_EMsgGCFantasyTeamRosterAddDropRequest = 7361
k_EMsgGCFantasyTeamRosterAddDropResponse = 7362
k_EMsgPresentedClientTerminateDlg = 7363
k_EMsgGCFantasyPlayerHisoricalStatsRequest = 7364
k_EMsgGCFantasyPlayerHisoricalStatsResponse = 7365
k_EMsgGCPCBangTimedRewardMessage = 7366
k_EMsgGCLobbyUpdateBroadcastChannelInfo = 7367
k_EMsgGCFantasyTeamTradesRequest = 7368
k_EMsgGCFantasyTeamTradesResponse = 7369
k_EMsgGCFantasyTeamTradeCancelRequest = 7370
k_EMsgGCFantasyTeamTradeCancelResponse = 7371
k_EMsgGCToGCGrantTournamentItem = 7372
k_EMsgGCProcessFantasyScheduledEvent = 7373
k_EMsgGCToGCGrantPCBangRewardItem = 7374
k_EMsgGCToGCUpgradeTwitchViewerItems = 7375
k_EMsgGCToGCGetLiveMatchAffiliates = 7376
k_EMsgGCToGCGetLiveMatchAffiliatesResponse = 7377
k_EMsgGCToGCUpdatePlayerPennantCounts = 7378
k_EMsgGCToGCGetPlayerPennantCounts = 7379
k_EMsgGCToGCGetPlayerPennantCountsResponse = 7380
k_EMsgGCGameMatchSignOutPermissionRequest = 7381
k_EMsgGCGameMatchSignOutPermissionResponse = 7382
k_EMsgDOTAChatChannelMemberUpdate = 7383
k_EMsgDOTAAwardEventPoints = 7384
k_EMsgDOTARedeemEventPrize = 7385
k_EMsgDOTARedeemEventPrizeResponse = 7386
k_EMsgDOTAGetEventPoints = 7387
k_EMsgDOTAGetEventPointsResponse = 7388
k_EMsgGCToGCSignoutAwardEventPoints = 7390
k_EMsgDOTASendFriendRecruits = 7393
k_EMsgDOTAFriendRecruitsRequest = 7394
k_EMsgDOTAFriendRecruitsResponse = 7395
k_EMsgDOTAFriendRecruitInviteAcceptDecline = 7396
k_EMsgGCPartyLeaderWatchGamePrompt = 7397
k_EMsgDOTAFrostivusTimeElapsed = 7398
k_EMsgDOTALiveLeagueGameUpdate = 7402
k_EMsgDOTAChatGetUserList = 7403
k_EMsgDOTAChatGetUserListResponse = 7404
k_EMsgGCCompendiumSetSelection = 7405
k_EMsgGCCompendiumDataRequest = 7406
k_EMsgGCCompendiumDataResponse = 7407
k_EMsgDOTAGetPlayerMatchHistory = 7408
k_EMsgDOTAGetPlayerMatchHistoryResponse = 7409
k_EMsgGCToGCMatchmakingAddParty = 7410
k_EMsgGCToGCMatchmakingRemoveParty = 7411
k_EMsgGCToGCMatchmakingRemoveAllParties = 7412
k_EMsgGCToGCMatchmakingMatchFound = 7413
k_EMsgGCToGCUpdateMatchManagementStats = 7414
k_EMsgGCToGCUpdateMatchmakingStats = 7415
k_EMsgGCToServerPingRequest = 7416
k_EMsgGCToServerPingResponse = 7417
k_EMsgGCToServerConsoleCommand = 7418
k_EMsgGCToGCUpdateLiveLeagueGameInfo = 7420
k_EMsgGCMakeOffering = 7423
k_EMsgGCRequestOfferings = 7424
k_EMsgGCRequestOfferingsResponse = 7425
k_EMsgGCToGCProcessMatchLeaver = 7426
k_EMsgGCNotificationsRequest = 7427
k_EMsgGCNotificationsResponse = 7428
k_EMsgGCToGCModifyNotification = 7429
k_EMsgGCToGCSetNewNotifications = 7430
k_EMsgGCToGCSetIsLeagueAdmin = 7431
k_EMsgGCLeagueAdminState = 7432
k_EMsgGCToGCSendLeagueAdminState = 7433
k_EMsgGCLeagueAdminList = 7434
k_EMsgGCNotificationsMarkReadRequest = 7435
k_EMsgGCFantasyMessageAdd = 7436
k_EMsgGCFantasyMessagesRequest = 7437
k_EMsgGCFantasyMessagesResponse = 7438
k_EMsgGCFantasyScheduledMatchesRequest = 7439
k_EMsgGCFantasyScheduledMatchesResponse = 7440
k_EMsgGCToGCGrantLeagueAccess = 7441
k_EMsgGCEventGameCreate = 7443
k_EMsgGCPerfectWorldUserLookupRequest = 7444
k_EMsgGCPerfectWorldUserLookupResponse = 7445
k_EMsgGCFantasyRemoveOwner = 7448
k_EMsgGCFantasyRemoveOwnerResponse = 7449
k_EMsgGCRequestBatchPlayerResources = 7450
k_EMsgGCRequestBatchPlayerResourcesResponse = 7451
k_EMsgGCToGCSendUpdateLeagues = 7452
k_EMsgGCCompendiumSetSelectionResponse = 7453
k_EMsgGCPlayerInfoRequest = 7454
k_EMsgGCPlayerInfo = 7455
k_EMsgGCPlayerInfoSubmit = 7456
k_EMsgGCPlayerInfoSubmitResponse = 7457
k_EMsgGCToGCGetAccountLevel = 7458
k_EMsgGCToGCGetAccountLevelResponse = 7459
k_EMsgGCToGCGetAccountPartner = 7460
k_EMsgGCToGCGetAccountPartnerResponse = 7461
k_EMsgGCToGCGetAccountProfile = 7462
k_EMsgGCToGCGetAccountProfileResponse = 7463
k_EMsgDOTAGetWeekendTourneySchedule = 7464
k_EMsgDOTAWeekendTourneySchedule = 7465
k_EMsgGCJoinableCustomGameModesRequest = 7466
k_EMsgGCJoinableCustomGameModesResponse = 7467
k_EMsgGCJoinableCustomLobbiesRequest = 7468
k_EMsgGCJoinableCustomLobbiesResponse = 7469
k_EMsgGCQuickJoinCustomLobby = 7470
k_EMsgGCQuickJoinCustomLobbyResponse = 7471
k_EMsgGCToGCGrantEventPointAction = 7472
k_EMsgServerGetEventPoints = 7473
k_EMsgServerGetEventPointsResponse = 7474
k_EMsgServerGrantSurveyPermission = 7475
k_EMsgServerGrantSurveyPermissionResponse = 7476
k_EMsgClientProvideSurveyResult = 7477
k_EMsgGCToGCSetCompendiumSelection = 7478
k_EMsgGCToGCUpdateTI4HeroQuest = 7480
k_EMsgGCCompendiumDataChanged = 7481
k_EMsgDOTAFantasyLeagueFindRequest = 7482
k_EMsgDOTAFantasyLeagueFindResponse = 7483
k_EMsgGCHasItemQuery = 7484
k_EMsgGCHasItemResponse = 7485
k_EMsgGCConsumeFantasyTicket = 7486
k_EMsgGCConsumeFantasyTicketFailure = 7487
k_EMsgGCToGCGrantEventPointActionMsg = 7488
k_EMsgClientToGCTrackDialogResult = 7489
k_EMsgGCFantasyLeaveLeagueRequest = 7490
k_EMsgGCFantasyLeaveLeagueResponse = 7491
k_EMsgGCToGCGetCompendiumSelections = 7492
k_EMsgGCToGCGetCompendiumSelectionsResponse = 7493
k_EMsgServerToGCMatchConnectionStats = 7494
k_EMsgGCToClientTournamentItemDrop = 7495
k_EMsgSQLDelayedGrantLeagueDrop = 7496
k_EMsgServerGCUpdateSpectatorCount = 7497
k_EMsgGCFantasyPlayerScoreDetailsRequest = 7499
k_EMsgGCFantasyPlayerScoreDetailsResponse = 7500
k_EMsgGCToGCEmoticonUnlock = 7501
k_EMsgSignOutDraftInfo = 7502
k_EMsgClientToGCEmoticonDataRequest = 7503
k_EMsgGCToClientEmoticonData = 7504
k_EMsgGCPracticeLobbyToggleBroadcastChannelCameramanStatus = 7505
k_EMsgGCToGCCreateWeekendTourneyRequest = 7506
k_EMsgGCToGCCreateWeekendTourneyResponse = 7507
k_EMsgClientToGCSetAdditionalEquips = 7513
k_EMsgClientToGCGetAdditionalEquips = 7514
k_EMsgClientToGCGetAdditionalEquipsResponse = 7515
k_EMsgServerToGCGetAdditionalEquips = 7516
k_EMsgServerToGCGetAdditionalEquipsResponse = 7517
k_EMsgDOTARedeemItem = 7518
k_EMsgDOTARedeemItemResponse = 7519
k_EMsgSQLGCToGCGrantAllHeroProgress = 7520
k_EMsgClientToGCGetAllHeroProgress = 7521
k_EMsgClientToGCGetAllHeroProgressResponse = 7522
k_EMsgGCToGCGetServerForClient = 7523
k_EMsgGCToGCGetServerForClientResponse = 7524
k_EMsgSQLProcessTournamentGameOutcome = 7525
k_EMsgSQLGrantTrophyToAccount = 7526
k_EMsgClientToGCGetTrophyList = 7527
k_EMsgClientToGCGetTrophyListResponse = 7528
k_EMsgGCToClientTrophyAwarded = 7529
k_EMsgGCGameBotMatchSignOut = 7530
k_EMsgGCGameBotMatchSignOutPermissionRequest = 7531
k_EMsgSignOutBotInfo = 7532
k_EMsgGCToGCUpdateProfileCards = 7533
k_EMsgClientToGCGetProfileCard = 7534
k_EMsgClientToGCGetProfileCardResponse = 7535
k_EMsgServerToGCGetProfileCard = 7536
k_EMsgServerToGCGetProfileCardResponse = 7537
k_EMsgClientToGCSetProfileCardSlots = 7538
k_EMsgGCToClientProfileCardUpdated = 7539
k_EMsgServerToGCVictoryPredictions = 7540
k_EMsgClientToGCMarkNotificationListRead = 7542
k_EMsgGCToClientNewNotificationAdded = 7543
k_EMsgServerToGCSuspiciousActivity = 7544
k_EMsgSignOutCommunicationSummary = 7545
k_EMsgServerToGCRequestStatus_Response = 7546
k_EMsgClientToGCCreateHeroStatue = 7547
k_EMsgGCToClientHeroStatueCreateResult = 7548
k_EMsgGCGCToLANServerRelayConnect = 7549
k_EMsgServerToGCGetIngameEventData = 7551
k_EMsgGCToGCUpdateIngameEventDataBroadcast = 7552
k_EMsgGCToServerIngameEventData_OraclePA = 7553
k_EMsgServerToGCReportKillSummaries = 7554
k_EMsgGCToGCReportKillSummaries = 7555
k_EMsgGCToGCUpdateAssassinMinigame = 7556
k_EMsgGCToGCFantasySetMatchLeague = 7557
k_EMsgClientToGCRecordCompendiumStats = 7558
k_EMsgGCItemEditorRequestLeagueInfo = 7559
k_EMsgGCItemEditorLeagueInfoResponse = 7560
k_EMsgGCToGCUpdatePlayerPredictions = 7561
k_EMsgGCToServerPredictionResult = 7562
k_EMsgServerToGCSignoutAwardAdditionalDrops = 7563
k_EMsgGCToGCSignoutAwardAdditionalDrops = 7564
k_EMsgGCToClientEventStatusChanged = 7565
k_EMsgGCHasItemDefsQuery = 7566
k_EMsgGCHasItemDefsResponse = 7567
k_EMsgGCToGCReplayMonitorValidateReplay = 7569
k_EMsgLobbyEventPoints = 7572
k_EMsgGCToGCGetCustomGameTickets = 7573
k_EMsgGCToGCGetCustomGameTicketsResponse = 7574
k_EMsgGCToGCCustomGamePlayed = 7576
k_EMsgGCToGCGrantEventPointsToUser = 7577
k_EMsgGCToGCSetEventMMPanicFlushTime = 7578
k_EMsgGameserverCrashReport = 7579
k_EMsgGameserverCrashReportResponse = 7580
k_EMsgGCToClientSteamDatagramTicket = 7581
k_EMsgGCToGCGrantEventOwnership = 7582
k_EMsgGCToGCSendAccountsEventPoints = 7583
k_EMsgClientToGCRerollPlayerChallenge = 7584
k_EMsgServerToGCRerollPlayerChallenge = 7585
k_EMsgGCRerollPlayerChallengeResponse = 7586
k_EMsgSignOutUpdatePlayerChallenge = 7587
k_EMsgClientToGCSetPartyLeader = 7588
k_EMsgClientToGCCancelPartyInvites = 7589
k_EMsgGCToGCMasterReloadAccount = 7590
k_EMsgSQLGrantLeagueMatchToTicketHolders = 7592
k_EMsgClientToGCSetAdditionalEquipsResponse = 7593
k_EMsgGCToGCEmoticonUnlockNoRollback = 7594
k_EMsgGCToGCGetCompendiumFanfare = 7595
k_EMsgServerToGCHoldEventPoints = 7596
k_EMsgSignOutReleaseEventPointHolds = 7597
k_EMsgGCToGCChatNewUserSession = 7598
k_EMsgClientToGCGetLeagueSeries = 7599
k_EMsgClientToGCGetLeagueSeriesResponse = 7600
k_EMsgSQLGCToGCSignoutUpdateLeagueSchedule = 7601
k_EMsgGCToServerUpdateBroadcastCheers = 7602
k_EMsgClientToGCApplyGemCombiner = 7603
k_EMsgClientToGCDOTACreateStaticRecipe = 7604
k_EMsgClientToGCDOTACreateStaticRecipeResponse = 7605
k_EMsgClientToGCGetAllHeroOrder = 7606
k_EMsgClientToGCGetAllHeroOrderResponse = 7607
k_EMsgSQLGCToGCGrantBadgePoints = 7608
k_EMsgGCToGCGetAccountMatchStatus = 7609
k_EMsgGCToGCGetAccountMatchStatusResponse = 7610
k_EMsgGCToGCCheckOwnsEntireEmoticonRange = 7611
k_EMsgGCToGCCheckOwnsEntireEmoticonRangeResponse = 7612
k_EMsgGCDev_GrantWarKill = 8001
k_EMsgServerToGCLockCharmTrading = 8004
k_EMsgClientToGCPlayerStatsRequest = 8006
k_EMsgGCToClientPlayerStatsResponse = 8007
k_EMsgGCClearPracticeLobbyTeam = 8008
k_EMsgClientToGCFindTopSourceTVGames = 8009
k_EMsgGCToClientFindTopSourceTVGamesResponse = 8010
k_EMsgGCLobbyList = 8011
k_EMsgGCLobbyListResponse = 8012
k_EMsgGCPlayerStatsMatchSignOut = 8013
k_EMsgClientToGCCustomGamePlayerCountRequest = 8014
k_EMsgGCToClientCustomGamePlayerCountResponse = 8015
k_EMsgClientToGCSocialFeedPostCommentRequest = 8016
k_EMsgGCToClientSocialFeedPostCommentResponse = 8017
k_EMsgClientToGCCustomGamesFriendsPlayedRequest = 8018
k_EMsgGCToClientCustomGamesFriendsPlayedResponse = 8019
k_EMsgClientToGCFriendsPlayedCustomGameRequest = 8020
k_EMsgGCToClientFriendsPlayedCustomGameResponse = 8021
k_EMsgClientToGCFeaturedHeroesRequest = 8022
k_EMsgGCToClientFeaturedHeroesResponse = 8023
k_EMsgGCTopCustomGamesList = 8024
k_EMsgClientToGCSocialMatchPostCommentRequest = 8025
k_EMsgGCToClientSocialMatchPostCommentResponse = 8026
k_EMsgClientToGCSocialMatchDetailsRequest = 8027
k_EMsgGCToClientSocialMatchDetailsResponse = 8028
k_EMsgClientToGCSetPartyOpen = 8029
k_EMsgClientToGCMergePartyInvite = 8030
k_EMsgGCToClientMergeGroupInviteReply = 8031
k_EMsgClientToGCMergePartyResponse = 8032
k_EMsgGCToClientMergePartyResponseReply = 8033
k_EMsgClientToGCGetProfileCardStats = 8034
k_EMsgClientToGCGetProfileCardStatsResponse = 8035
k_EMsgClientToGCTopLeagueMatchesRequest = 8036
k_EMsgClientToGCTopFriendMatchesRequest = 8037
k_EMsgGCToClientProfileCardStatsUpdated = 8040
k_EMsgServerToGCRealtimeStats = 8041
k_EMsgGCToServerRealtimeStatsStartStop = 8042
k_EMsgGCToGCGetServersForClients = 8045
k_EMsgGCToGCGetServersForClientsResponse = 8046
k_EMsgGCPracticeLobbyKickFromTeam = 8047
k_EMsgDOTAChatGetMemberCount = 8048
k_EMsgDOTAChatGetMemberCountResponse = 8049
k_EMsgClientToGCSocialFeedPostMessageRequest = 8050
k_EMsgGCToClientSocialFeedPostMessageResponse = 8051
k_EMsgCustomGameListenServerStartedLoading = 8052
k_EMsgCustomGameClientFinishedLoading = 8053
k_EMsgGCPracticeLobbyCloseBroadcastChannel = 8054
k_EMsgGCStartFindingMatchResponse = 8055
k_EMsgSQLGCToGCGrantAccountFlag = 8057
k_EMsgGCToGCGetAccountFlags = 8058
k_EMsgGCToGCGetAccountFlagsResponse = 8059
k_EMsgSignOutWagerStats = 8060
k_EMsgGCToClientTopLeagueMatchesResponse = 8061
k_EMsgGCToClientTopFriendMatchesResponse = 8062
k_EMsgClientToGCMatchesMinimalRequest = 8063
k_EMsgClientToGCMatchesMinimalResponse = 8064
k_EMsgGCToGCGetProfileBadgePoints = 8065
k_EMsgGCToGCGetProfileBadgePointsResponse = 8066
k_EMsgGCToClientChatRegionsEnabled = 8067
k_EMsgClientToGCPingData = 8068
k_EMsgServerToGCMatchDetailsRequest = 8069
k_EMsgGCToServerMatchDetailsResponse = 8070
k_EMsgGCToGCEnsureAccountInParty = 8071
k_EMsgGCToGCEnsureAccountInPartyResponse = 8072
k_EMsgClientToGCGetProfileTickets = 8073
k_EMsgClientToGCGetProfileTicketsResponse = 8074
k_EMsgGCToClientMatchGroupsVersion = 8075
k_EMsgClientToGCH264Unsupported = 8076
k_EMsgClientToGCRequestH264Support = 8077
k_EMsgClientToGCGetQuestProgress = 8078
k_EMsgClientToGCGetQuestProgressResponse = 8079
k_EMsgSignOutXPCoins = 8080
k_EMsgGCToClientMatchSignedOut = 8081
k_EMsgGCGetHeroStatsHistory = 8082
k_EMsgGCGetHeroStatsHistoryResponse = 8083
k_EMsgClientToGCPrivateChatInvite = 8084
k_EMsgClientToGCPrivateChatKick = 8088
k_EMsgClientToGCPrivateChatPromote = 8089
k_EMsgClientToGCPrivateChatDemote = 8090
k_EMsgGCToClientPrivateChatResponse = 8091
k_EMsgClientToGCPrivateChatInfoRequest = 8092
k_EMsgGCToClientPrivateChatInfoResponse = 8093
k_EMsgClientToGCLatestConductScorecardRequest = 8095
k_EMsgClientToGCLatestConductScorecard = 8096
k_EMsgServerToGCPostMatchTip = 8097
k_EMsgServerToGCPostMatchTipResponse = 8098
k_EMsgClientToGCWageringRequest = 8099
k_EMsgGCToClientWageringResponse = 8100
k_EMsgClientToGCMysteryItem = 8101
k_EMsgGCToClientMysteryItemResponse = 8102
k_EMsgClientToGCEventGoalsRequest = 8103
k_EMsgClientToGCEventGoalsResponse = 8104
k_EMsgClientToGCLeaguePredictions = 8106
k_EMsgGCToClientLeaguePredictionsResponse = 8107
k_EMsgGCToGCLeaguePredictionsUpdate = 8108
k_EMsgClientToGCSuspiciousActivity = 8109
k_EMsgGCToGCAddUserToPostGameChat = 8110
k_EMsgClientToGCHasPlayerVotedForMVP = 8111
k_EMsgClientToGCHasPlayerVotedForMVPResponse = 8112
k_EMsgClientToGCVoteForMVP = 8113
k_EMsgClientToGCVoteForMVPResponse = 8114
k_EMsgGCToGCGetEventOwnership = 8115
k_EMsgGCToGCGetEventOwnershipResponse = 8116
k_EMsgGCToClientAutomatedTournamentStateChange = 8117
k_EMsgClientToGCWeekendTourneyOpts = 8118
k_EMsgClientToGCWeekendTourneyOptsResponse = 8119
k_EMsgClientToGCWeekendTourneyLeave = 8120
k_EMsgClientToGCWeekendTourneyLeaveResponse = 8121
k_EMsgClientToGCTeammateStatsRequest = 8124
k_EMsgClientToGCTeammateStatsResponse = 8125
k_EMsgClientToGCGetGiftPermissions = 8126
k_EMsgClientToGCGetGiftPermissionsResponse = 8127
k_EMsgClientToGCVoteForArcana = 8128
k_EMsgClientToGCVoteForArcanaResponse = 8129
k_EMsgClientToGCRequestArcanaVotesRemaining = 8130
k_EMsgClientToGCRequestArcanaVotesRemainingResponse = 8131
k_EMsgGCTransferTeamAdminResponse = 8132
k_EMsgGCChangeTeamSub = 8133
k_EMsgGCChangeTeamSubResponse = 8134
k_EMsgGCToClientTeamInfo = 8135
k_EMsgGCToClientTeamsInfo = 8136
k_EMsgClientToGCMyTeamInfoRequest = 8137
k_EMsgClientToGCRequestEventPointLog = 8138
k_EMsgClientToGCRequestEventPointLogResponse = 8139
k_EMsgClientToGCPublishUserStat = 8140
k_EMsgGCToGCSignoutSpendWager = 8141
k_EMsgClientToGCRedeemReward = 8142
k_EMsgGCToClientRedeemRewardResponse = 8143
k_EMsgGCSubmitLobbyMVPVote = 8144
k_EMsgGCSubmitLobbyMVPVoteResponse = 8145
k_EMsgClientToGCRequestLinaPlaysRemaining = 8146
k_EMsgClientToGCRequestLinaPlaysRemainingResponse = 8147
k_EMsgClientToGCRequestLinaGameResult = 8148
k_EMsgClientToGCRequestLinaGameResultResponse = 8149
k_EMsgSignOutCommunityGoalProgress = 8150
k_EMsgGCToClientLobbyMVPNotifyRecipient = 8151
k_EMsgGCToClientLobbyMVPAwarded = 8152
k_EMsgGCToClientQuestProgressUpdated = 8153
k_EMsgGCToClientWageringUpdate = 8154
k_EMsgGCToClientArcanaVotesUpdate = 8155
k_EMsgClientToGCAddTI6TreeProgress = 8156
k_EMsgClientToGCSetSpectatorLobbyDetails = 8157
k_EMsgClientToGCSetSpectatorLobbyDetailsResponse = 8158
k_EMsgClientToGCCreateSpectatorLobby = 8159
k_EMsgClientToGCCreateSpectatorLobbyResponse = 8160
k_EMsgClientToGCSpectatorLobbyList = 8161
k_EMsgClientToGCSpectatorLobbyListResponse = 8162
k_EMsgSpectatorLobbyGameDetails = 8163
k_EMsgServerToGCStartCompendiumInGamePredictions = 8164
k_EMsgServerToGCEndCompendiumInGamePredictions = 8165
k_EMsgServerToGCCompendiumInGamePredictionResults = 8166
k_EMsgServerToGCCloseCompendiumInGamePredictionVoting = 8167
k_EMsgClientToGCOpenPlayerCardPack = 8168
k_EMsgClientToGCOpenPlayerCardPackResponse = 8169
k_EMsgClientToGCSelectCompendiumInGamePrediction = 8170
k_EMsgClientToGCSelectCompendiumInGamePredictionResponse = 8171
k_EMsgClientToGCWeekendTourneyGetPlayerStats = 8172
k_EMsgClientToGCWeekendTourneyGetPlayerStatsResponse = 8173
k_EMsgClientToGCRecyclePlayerCard = 8174
k_EMsgClientToGCRecyclePlayerCardResponse = 8175
k_EMsgClientToGCCreatePlayerCardPack = 8176
k_EMsgClientToGCCreatePlayerCardPackResponse = 8177
k_EMsgClientToGCGetPlayerCardRosterRequest = 8178
k_EMsgClientToGCGetPlayerCardRosterResponse = 8179
k_EMsgClientToGCSetPlayerCardRosterRequest = 8180
k_EMsgClientToGCSetPlayerCardRosterResponse = 8181
k_EMsgServerToGCStartCompendiumInGamePredictionsResponse = 8182
k_EMsgServerToGCCloseCompendiumInGamePredictionVotingResponse = 8183
k_EMsgServerToGCEndCompendiumInGamePredictionsResponse = 8184
k_EMsgServerToGCCompendiumInGamePredictionResultsResponse = 8185
k_EMsgLobbyBattleCupVictory = 8186
k_EMsgGCGetPlayerCardItemInfo = 8187
k_EMsgGCGetPlayerCardItemInfoResponse = 8188
k_EMsgClientToGCRequestSteamDatagramTicket = 8189
k_EMsgClientToGCRequestSteamDatagramTicketResponse = 8190
k_EMsgGCToClientBattlePassRollupRequest = 8191
k_EMsgGCToClientBattlePassRollupResponse = 8192
k_EMsgClientToGCTransferSeasonalMMRRequest = 8193
k_EMsgClientToGCTransferSeasonalMMRResponse = 8194
k_EMsgGCToGCPublicChatCommunicationBan = 8195
k_EMsgGCToGCUpdateAccountPublicChatBan = 8196
k_EMsgGCChatReportPublicSpam = 8197
k_EMsgClientToGCSetPartyBuilderOptions = 8198
k_EMsgClientToGCSetPartyBuilderOptionsResponse = 8199
k_EMsgGCToClientBattlePassRollupListRequest = 8205
k_EMsgGCToClientBattlePassRollupListResponse = 8206
k_EMsgDOTASetFavoriteTeam = 8204


DESCRIPTOR.enum_types_by_name['EDOTAGCMsg'] = _EDOTAGCMSG


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
# @@protoc_insertion_point(module_scope)
